var searchData=
[
  ['setoption',['setOption',['../classssh_1_1Session.html#a5b1840081e321b82cd19af1b3f98e069',1,'ssh::Session::setOption(enum ssh_options_e type, const char *option)'],['../classssh_1_1Session.html#a21e712ae0b5446e84af31e011a59463c',1,'ssh::Session::setOption(enum ssh_options_e type, long int option)'],['../classssh_1_1Session.html#a4f037f88f67365ddd1b099e631fb7682',1,'ssh::Session::setOption(enum ssh_options_e type, void *option)']]],
  ['sftp_5fasync_5fread',['sftp_async_read',['../group__libssh__sftp.html#ga46717d68301346682d5650e37eae6503',1,'sftp.h']]],
  ['sftp_5fasync_5fread_5fbegin',['sftp_async_read_begin',['../group__libssh__sftp.html#ga7863299ed9a2e74d684500b79f430ad7',1,'sftp.h']]],
  ['sftp_5fattributes_5ffree',['sftp_attributes_free',['../group__libssh__sftp.html#ga8453428c2eac62070174a487f3c43f85',1,'sftp.h']]],
  ['sftp_5fcanonicalize_5fpath',['sftp_canonicalize_path',['../group__libssh__sftp.html#gab4860a441da019060f78c8d236d9ec91',1,'sftp.h']]],
  ['sftp_5fchmod',['sftp_chmod',['../group__libssh__sftp.html#gaeb224e6feefedb94e7f1325cca50ecc0',1,'sftp.h']]],
  ['sftp_5fchown',['sftp_chown',['../group__libssh__sftp.html#gaa13f6aea1d3f67ddb73ffccc693018d0',1,'sftp.h']]],
  ['sftp_5fclose',['sftp_close',['../group__libssh__sftp.html#ga2a303b07042530a0c653c05ea6fa240b',1,'sftp.h']]],
  ['sftp_5fclosedir',['sftp_closedir',['../group__libssh__sftp.html#ga25fb798c65ef75e9a17d908ffa4603c5',1,'sftp.h']]],
  ['sftp_5fdir_5feof',['sftp_dir_eof',['../group__libssh__sftp.html#gab58f3f20aba237bc19f2bb91e6159655',1,'sftp.h']]],
  ['sftp_5fextension_5fsupported',['sftp_extension_supported',['../group__libssh__sftp.html#gaa33d3cb069d6f8762498bfb6d54f564e',1,'sftp.h']]],
  ['sftp_5fextensions_5fget_5fcount',['sftp_extensions_get_count',['../group__libssh__sftp.html#ga50433a560404a76c473873f2a12e5a6c',1,'sftp.h']]],
  ['sftp_5fextensions_5fget_5fdata',['sftp_extensions_get_data',['../group__libssh__sftp.html#ga91e75018572ae202de807676aa13e78b',1,'sftp.h']]],
  ['sftp_5fextensions_5fget_5fname',['sftp_extensions_get_name',['../group__libssh__sftp.html#gafc21d4e462d4ca7a70ab014267255cc6',1,'sftp.h']]],
  ['sftp_5ffile_5fset_5fblocking',['sftp_file_set_blocking',['../group__libssh__sftp.html#gaaf4ec4504dfcf9b9c911684f1ab782a3',1,'sftp.h']]],
  ['sftp_5ffile_5fset_5fnonblocking',['sftp_file_set_nonblocking',['../group__libssh__sftp.html#ga0616dcf424f8ee8a3563a1d5783314e5',1,'sftp.h']]],
  ['sftp_5ffree',['sftp_free',['../group__libssh__sftp.html#ga7b6bfbd5e81da1cdddf14a44caf21d37',1,'sftp.h']]],
  ['sftp_5ffstat',['sftp_fstat',['../group__libssh__sftp.html#ga056adc7ba4ee85db1984d9bed5d41a87',1,'sftp.h']]],
  ['sftp_5ffstatvfs',['sftp_fstatvfs',['../group__libssh__sftp.html#ga7602d0324fadae764b90dfe2496710c9',1,'sftp.h']]],
  ['sftp_5ffsync',['sftp_fsync',['../group__libssh__sftp.html#gaee9b3438bfa88f70e2922e1b23c0757a',1,'sftp.h']]],
  ['sftp_5fget_5ferror',['sftp_get_error',['../group__libssh__sftp.html#ga5a66187e77cd309bad8be9088f4fa299',1,'sftp.h']]],
  ['sftp_5finit',['sftp_init',['../group__libssh__sftp.html#gab8ec37b2cb85c9bb47341683f43f0841',1,'sftp.h']]],
  ['sftp_5flstat',['sftp_lstat',['../group__libssh__sftp.html#ga6b4d1de2f8f39fa0ca55cb0bbfe81ecf',1,'sftp.h']]],
  ['sftp_5fmkdir',['sftp_mkdir',['../group__libssh__sftp.html#ga077f9b979e13a505507f7585833245dc',1,'sftp.h']]],
  ['sftp_5fnew',['sftp_new',['../group__libssh__sftp.html#gae84eeb5a1af9d49db10f17a060151e97',1,'sftp.h']]],
  ['sftp_5fnew_5fchannel',['sftp_new_channel',['../group__libssh__sftp.html#gaad24f54e6ba95ee5c6f0ca0eb1c67433',1,'sftp.h']]],
  ['sftp_5fopen',['sftp_open',['../group__libssh__sftp.html#gaad64845af1100fb9325f20812f38da3b',1,'sftp.h']]],
  ['sftp_5fopendir',['sftp_opendir',['../group__libssh__sftp.html#gab7fc8fbf6a791548547992bc60ccda4b',1,'sftp.h']]],
  ['sftp_5fread',['sftp_read',['../group__libssh__sftp.html#gaba8095f72d8287e74b440f9984c05385',1,'sftp.h']]],
  ['sftp_5freaddir',['sftp_readdir',['../group__libssh__sftp.html#ga1fbb11950e06e26a2037d6a084d1b7a9',1,'sftp.h']]],
  ['sftp_5freadlink',['sftp_readlink',['../group__libssh__sftp.html#gae2838bb68cb223a8bc90937b1a4641d9',1,'sftp.h']]],
  ['sftp_5frename',['sftp_rename',['../group__libssh__sftp.html#ga0df9d2b4c2ce47ccf46d6461323ec28b',1,'sftp.h']]],
  ['sftp_5frewind',['sftp_rewind',['../group__libssh__sftp.html#gab3d37bdb517ba1c4be730d7d26962e04',1,'sftp.h']]],
  ['sftp_5frmdir',['sftp_rmdir',['../group__libssh__sftp.html#gab098f783ff8ce13a5b3e81d9bc511f9c',1,'sftp.h']]],
  ['sftp_5fseek',['sftp_seek',['../group__libssh__sftp.html#ga7fc35b5df3789198706c1e0a2dc4d16d',1,'sftp.h']]],
  ['sftp_5fseek64',['sftp_seek64',['../group__libssh__sftp.html#ga2197752634a47a6bed0c0dad41a5d0b9',1,'sftp.h']]],
  ['sftp_5fserver_5fversion',['sftp_server_version',['../group__libssh__sftp.html#gabbfacf308d2116ae09b1ca4f901afe2d',1,'sftp.h']]],
  ['sftp_5fsetstat',['sftp_setstat',['../group__libssh__sftp.html#gac0cdfade4c8739781eddefe32751e6fd',1,'sftp.h']]],
  ['sftp_5fstat',['sftp_stat',['../group__libssh__sftp.html#ga8a31613141c2502cc708010cec30bc3c',1,'sftp.h']]],
  ['sftp_5fstatvfs',['sftp_statvfs',['../group__libssh__sftp.html#gaeba8a61ff5fcc26b5c69127838c9e8a7',1,'sftp.h']]],
  ['sftp_5fstatvfs_5ffree',['sftp_statvfs_free',['../group__libssh__sftp.html#ga11326e158508ad2a5b7a8b1508bdb9c4',1,'sftp.h']]],
  ['sftp_5fsymlink',['sftp_symlink',['../group__libssh__sftp.html#gadc73b93adecad2c7db6fa95158f6effc',1,'sftp.h']]],
  ['sftp_5ftell',['sftp_tell',['../group__libssh__sftp.html#ga5bac97b9fa8a24fc38a842900ba9a1f6',1,'sftp.h']]],
  ['sftp_5ftell64',['sftp_tell64',['../group__libssh__sftp.html#ga99175b28a6ac39e21bad4cc0a28e9e13',1,'sftp.h']]],
  ['sftp_5funlink',['sftp_unlink',['../group__libssh__sftp.html#ga67b7b7ff738125ac90da041635a5bf53',1,'sftp.h']]],
  ['sftp_5futimes',['sftp_utimes',['../group__libssh__sftp.html#ga1a6db354d48bdba3acd33805942162d8',1,'sftp.h']]],
  ['sftp_5fwrite',['sftp_write',['../group__libssh__sftp.html#gaf270f5ad058082ca836a456a090ad314',1,'sftp.h']]],
  ['silentdisconnect',['silentDisconnect',['../classssh_1_1Session.html#a15b2a58607cc42628e17c94c8f7eb793',1,'ssh::Session']]],
  ['ssh_5fadd_5fchannel_5fcallbacks',['ssh_add_channel_callbacks',['../group__libssh__callbacks.html#ga2fd83df19998902f84f951fc47def83e',1,'ssh_add_channel_callbacks(ssh_channel channel, ssh_channel_callbacks cb):&#160;callbacks.c'],['../group__libssh__callbacks.html#ga2fd83df19998902f84f951fc47def83e',1,'ssh_add_channel_callbacks(ssh_channel channel, ssh_channel_callbacks cb):&#160;callbacks.c']]],
  ['ssh_5fbasename',['ssh_basename',['../group__libssh__misc.html#ga83b053a8bdf80eea5ebc662e5098a52b',1,'ssh_basename(const char *path):&#160;misc.c'],['../group__libssh__misc.html#ga83b053a8bdf80eea5ebc662e5098a52b',1,'ssh_basename(const char *path):&#160;misc.c']]],
  ['ssh_5fbind_5faccept',['ssh_bind_accept',['../group__libssh__server.html#ga6609243446f1650243101e0a779dc822',1,'bind.c']]],
  ['ssh_5fbind_5faccept_5ffd',['ssh_bind_accept_fd',['../group__libssh__server.html#ga142f1e2f79f6623f14dcfa40dccaa061',1,'bind.c']]],
  ['ssh_5fbind_5ffd_5ftoaccept',['ssh_bind_fd_toaccept',['../group__libssh__server.html#gab69593f009137ccabafc18a98bd55546',1,'bind.c']]],
  ['ssh_5fbind_5ffree',['ssh_bind_free',['../group__libssh__server.html#gaa7650d22d982a82bf328345c04948cdf',1,'bind.c']]],
  ['ssh_5fbind_5fget_5ffd',['ssh_bind_get_fd',['../group__libssh__server.html#ga2b0d1842bf3892ce8b5ebd6c0c7db735',1,'bind.c']]],
  ['ssh_5fbind_5flisten',['ssh_bind_listen',['../group__libssh__server.html#gaee5406f486d73aad765cab4c445f2f63',1,'bind.c']]],
  ['ssh_5fbind_5fnew',['ssh_bind_new',['../group__libssh__server.html#ga4e4edf0cfd185a335d08e6e610aed77e',1,'bind.c']]],
  ['ssh_5fbind_5fset_5fblocking',['ssh_bind_set_blocking',['../group__libssh__server.html#gaf7e6f23c6934892d6a96011456b6c280',1,'bind.c']]],
  ['ssh_5fbind_5fset_5fcallbacks',['ssh_bind_set_callbacks',['../group__libssh__server.html#gaaa9bf406809735d4afc75ecd482ba89d',1,'bind.c']]],
  ['ssh_5fbind_5fset_5ffd',['ssh_bind_set_fd',['../group__libssh__server.html#gacbba3e298a4493c7b9bfbee514df199c',1,'bind.c']]],
  ['ssh_5fblocking_5fflush',['ssh_blocking_flush',['../group__libssh__session.html#ga60da8e2c47897a209a455923c35d52d8',1,'ssh_blocking_flush(ssh_session session, int timeout):&#160;session.c'],['../group__libssh__session.html#ga60da8e2c47897a209a455923c35d52d8',1,'ssh_blocking_flush(ssh_session session, int timeout):&#160;session.c']]],
  ['ssh_5fbuffer_5fadd_5fdata',['ssh_buffer_add_data',['../group__libssh__buffer.html#ga3bf82f0f310311432410f9393ebab528',1,'buffer.c']]],
  ['ssh_5fbuffer_5fallocate_5fsize',['ssh_buffer_allocate_size',['../group__libssh__buffer.html#gad9103e11e347e99cf35f027e81d969f5',1,'ssh_buffer_allocate_size(struct ssh_buffer_struct *buffer, uint32_t len):&#160;buffer.c'],['../group__libssh__buffer.html#gad9103e11e347e99cf35f027e81d969f5',1,'ssh_buffer_allocate_size(struct ssh_buffer_struct *buffer, uint32_t len):&#160;buffer.c']]],
  ['ssh_5fbuffer_5ffree',['ssh_buffer_free',['../group__libssh__buffer.html#ga608cf73226454f21e8b2f9f1d838c5fc',1,'buffer.c']]],
  ['ssh_5fbuffer_5fget',['ssh_buffer_get',['../group__libssh__buffer.html#ga3577f5f4102e8010b281837b7812f261',1,'buffer.c']]],
  ['ssh_5fbuffer_5fget_5fdata',['ssh_buffer_get_data',['../group__libssh__buffer.html#ga2664b48795a4cba70a424e7704bdbcf2',1,'buffer.c']]],
  ['ssh_5fbuffer_5fget_5flen',['ssh_buffer_get_len',['../group__libssh__buffer.html#gad1594908ed57799f4a84066f47c3e7c0',1,'buffer.c']]],
  ['ssh_5fbuffer_5fnew',['ssh_buffer_new',['../group__libssh__buffer.html#ga7ecc914104a5bf0da485d3e42f6a7d3b',1,'ssh_buffer_new(void):&#160;buffer.c'],['../group__libssh__buffer.html#ga7ecc914104a5bf0da485d3e42f6a7d3b',1,'ssh_buffer_new(void):&#160;buffer.c']]],
  ['ssh_5fbuffer_5freinit',['ssh_buffer_reinit',['../group__libssh__buffer.html#gad877da63fd8d9a0ee00859bfbacf1eda',1,'buffer.c']]],
  ['ssh_5fbuffer_5fset_5fsecure',['ssh_buffer_set_secure',['../group__libssh__buffer.html#gade0108b17f43b5269b92456a785df126',1,'ssh_buffer_set_secure(ssh_buffer buffer):&#160;buffer.c'],['../group__libssh__buffer.html#gade0108b17f43b5269b92456a785df126',1,'ssh_buffer_set_secure(ssh_buffer buffer):&#160;buffer.c']]],
  ['ssh_5fbuffer_5fvalidate_5flength',['ssh_buffer_validate_length',['../group__libssh__buffer.html#ga49d552059803b03f1c305619cba34e24',1,'ssh_buffer_validate_length(struct ssh_buffer_struct *buffer, size_t len):&#160;buffer.c'],['../group__libssh__buffer.html#ga49d552059803b03f1c305619cba34e24',1,'ssh_buffer_validate_length(struct ssh_buffer_struct *buffer, size_t len):&#160;buffer.c']]],
  ['ssh_5fchannel_5faccept_5fforward',['ssh_channel_accept_forward',['../group__libssh__channel.html#ga490e4b0a7adc022507b7f165b336afe4',1,'ssh_channel_accept_forward(ssh_session session, int timeout_ms, int *destination_port):&#160;channels.c'],['../group__libssh__channel.html#ga490e4b0a7adc022507b7f165b336afe4',1,'ssh_channel_accept_forward(ssh_session session, int timeout_ms, int *destination_port):&#160;channels.c']]],
  ['ssh_5fchannel_5faccept_5fx11',['ssh_channel_accept_x11',['../group__libssh__channel.html#ga548bd0f77a50b7c8180942544b375866',1,'ssh_channel_accept_x11(ssh_channel channel, int timeout_ms):&#160;channels.c'],['../group__libssh__channel.html#ga548bd0f77a50b7c8180942544b375866',1,'ssh_channel_accept_x11(ssh_channel channel, int timeout_ms):&#160;channels.c']]],
  ['ssh_5fchannel_5fcancel_5fforward',['ssh_channel_cancel_forward',['../group__libssh__channel.html#ga3bff751afc5ecb5bbf9d6447e4e5370f',1,'ssh_channel_cancel_forward(ssh_session session, const char *address, int port):&#160;channels.c'],['../group__libssh__channel.html#ga3bff751afc5ecb5bbf9d6447e4e5370f',1,'ssh_channel_cancel_forward(ssh_session session, const char *address, int port):&#160;channels.c']]],
  ['ssh_5fchannel_5fchange_5fpty_5fsize',['ssh_channel_change_pty_size',['../group__libssh__channel.html#gaf5d55c90f3d98c583df23d21905c1127',1,'ssh_channel_change_pty_size(ssh_channel channel, int cols, int rows):&#160;channels.c'],['../group__libssh__channel.html#gaf5d55c90f3d98c583df23d21905c1127',1,'ssh_channel_change_pty_size(ssh_channel channel, int cols, int rows):&#160;channels.c']]],
  ['ssh_5fchannel_5fclose',['ssh_channel_close',['../group__libssh__channel.html#ga238f07e0455456a5bfd8a49ead917732',1,'ssh_channel_close(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#ga238f07e0455456a5bfd8a49ead917732',1,'ssh_channel_close(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5ffree',['ssh_channel_free',['../group__libssh__channel.html#gad1417f9eae8928fed20faafe2d9dbfff',1,'ssh_channel_free(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gad1417f9eae8928fed20faafe2d9dbfff',1,'ssh_channel_free(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fget_5fexit_5fstatus',['ssh_channel_get_exit_status',['../group__libssh__channel.html#ga9eea019dd0bbaa8a817fff2c762d1a2d',1,'ssh_channel_get_exit_status(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#ga9eea019dd0bbaa8a817fff2c762d1a2d',1,'ssh_channel_get_exit_status(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fget_5fsession',['ssh_channel_get_session',['../group__libssh__channel.html#ga747aa5315575aa7ac9d8367c7372d8dd',1,'ssh_channel_get_session(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#ga747aa5315575aa7ac9d8367c7372d8dd',1,'ssh_channel_get_session(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fis_5fclosed',['ssh_channel_is_closed',['../group__libssh__channel.html#gab2720b44cb7f1dfe2b38ffe07c2f45c7',1,'ssh_channel_is_closed(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gab2720b44cb7f1dfe2b38ffe07c2f45c7',1,'ssh_channel_is_closed(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fis_5feof',['ssh_channel_is_eof',['../group__libssh__channel.html#gab535264029443d77214c0615a0788b0a',1,'ssh_channel_is_eof(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gab535264029443d77214c0615a0788b0a',1,'ssh_channel_is_eof(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fis_5fopen',['ssh_channel_is_open',['../group__libssh__channel.html#gaaafcda943c96ddb91e5c28c0bdee7045',1,'ssh_channel_is_open(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gaaafcda943c96ddb91e5c28c0bdee7045',1,'ssh_channel_is_open(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5flisten_5fforward',['ssh_channel_listen_forward',['../group__libssh__channel.html#ga758cda957227751870c8772df46e5b39',1,'ssh_channel_listen_forward(ssh_session session, const char *address, int port, int *bound_port):&#160;channels.c'],['../group__libssh__channel.html#ga758cda957227751870c8772df46e5b39',1,'ssh_channel_listen_forward(ssh_session session, const char *address, int port, int *bound_port):&#160;channels.c']]],
  ['ssh_5fchannel_5fnew',['ssh_channel_new',['../group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc',1,'ssh_channel_new(ssh_session session):&#160;channels.c'],['../group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc',1,'ssh_channel_new(ssh_session session):&#160;channels.c']]],
  ['ssh_5fchannel_5fopen_5fauth_5fagent',['ssh_channel_open_auth_agent',['../group__libssh__channel.html#ga6c4d4f5436dd5be58973606c6bcd8bb4',1,'ssh_channel_open_auth_agent(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#ga6c4d4f5436dd5be58973606c6bcd8bb4',1,'ssh_channel_open_auth_agent(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fopen_5fforward',['ssh_channel_open_forward',['../group__libssh__channel.html#gae86b0704a1f2bdebb268b55567f7f47b',1,'ssh_channel_open_forward(ssh_channel channel, const char *remotehost, int remoteport, const char *sourcehost, int localport):&#160;channels.c'],['../group__libssh__channel.html#gae86b0704a1f2bdebb268b55567f7f47b',1,'ssh_channel_open_forward(ssh_channel channel, const char *remotehost, int remoteport, const char *sourcehost, int localport):&#160;channels.c']]],
  ['ssh_5fchannel_5fopen_5fsession',['ssh_channel_open_session',['../group__libssh__channel.html#gaf051dd30d75bf6dc45d1a5088cf970bd',1,'ssh_channel_open_session(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gaf051dd30d75bf6dc45d1a5088cf970bd',1,'ssh_channel_open_session(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fpoll',['ssh_channel_poll',['../group__libssh__channel.html#ga157f7d1df5de07ec6c6976e2034ba6e2',1,'ssh_channel_poll(ssh_channel channel, int is_stderr):&#160;channels.c'],['../group__libssh__channel.html#ga157f7d1df5de07ec6c6976e2034ba6e2',1,'ssh_channel_poll(ssh_channel channel, int is_stderr):&#160;channels.c']]],
  ['ssh_5fchannel_5fpoll_5ftimeout',['ssh_channel_poll_timeout',['../group__libssh__channel.html#gab56c7b7959e4c23959f2989468811661',1,'ssh_channel_poll_timeout(ssh_channel channel, int timeout, int is_stderr):&#160;channels.c'],['../group__libssh__channel.html#gab56c7b7959e4c23959f2989468811661',1,'ssh_channel_poll_timeout(ssh_channel channel, int timeout, int is_stderr):&#160;channels.c']]],
  ['ssh_5fchannel_5fread',['ssh_channel_read',['../group__libssh__channel.html#gac92381c4c5d4a7eab35f6e84686f033d',1,'ssh_channel_read(ssh_channel channel, void *dest, uint32_t count, int is_stderr):&#160;channels.c'],['../group__libssh__channel.html#gac92381c4c5d4a7eab35f6e84686f033d',1,'ssh_channel_read(ssh_channel channel, void *dest, uint32_t count, int is_stderr):&#160;channels.c']]],
  ['ssh_5fchannel_5fread_5fnonblocking',['ssh_channel_read_nonblocking',['../group__libssh__channel.html#gaaca5a3fbe9839c3ffb37b746afc35f4c',1,'ssh_channel_read_nonblocking(ssh_channel channel, void *dest, uint32_t count, int is_stderr):&#160;channels.c'],['../group__libssh__channel.html#gaaca5a3fbe9839c3ffb37b746afc35f4c',1,'ssh_channel_read_nonblocking(ssh_channel channel, void *dest, uint32_t count, int is_stderr):&#160;channels.c']]],
  ['ssh_5fchannel_5fread_5ftimeout',['ssh_channel_read_timeout',['../group__libssh__channel.html#ga2f4e02cb3b3adbc30a534623164068fd',1,'ssh_channel_read_timeout(ssh_channel channel, void *dest, uint32_t count, int is_stderr, int timeout_ms):&#160;channels.c'],['../group__libssh__channel.html#ga2f4e02cb3b3adbc30a534623164068fd',1,'ssh_channel_read_timeout(ssh_channel channel, void *dest, uint32_t count, int is_stderr, int timeout_ms):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fauth_5fagent',['ssh_channel_request_auth_agent',['../group__libssh__channel.html#gab2e28b520b8f8fe5ff5626de2a4113d9',1,'ssh_channel_request_auth_agent(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gab2e28b520b8f8fe5ff5626de2a4113d9',1,'ssh_channel_request_auth_agent(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fenv',['ssh_channel_request_env',['../group__libssh__channel.html#ga7aede2f9af4c494ff9e41fc08a4572f1',1,'ssh_channel_request_env(ssh_channel channel, const char *name, const char *value):&#160;channels.c'],['../group__libssh__channel.html#ga7aede2f9af4c494ff9e41fc08a4572f1',1,'ssh_channel_request_env(ssh_channel channel, const char *name, const char *value):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fexec',['ssh_channel_request_exec',['../group__libssh__channel.html#ga567d509183ade0a77190f390e2b5747d',1,'ssh_channel_request_exec(ssh_channel channel, const char *cmd):&#160;channels.c'],['../group__libssh__channel.html#ga567d509183ade0a77190f390e2b5747d',1,'ssh_channel_request_exec(ssh_channel channel, const char *cmd):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fpty',['ssh_channel_request_pty',['../group__libssh__channel.html#ga37c1cec33fe5a2f184768aba52e3a0db',1,'ssh_channel_request_pty(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#ga37c1cec33fe5a2f184768aba52e3a0db',1,'ssh_channel_request_pty(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fpty_5fsize',['ssh_channel_request_pty_size',['../group__libssh__channel.html#gabb175414352256e1602286e0ab50886c',1,'ssh_channel_request_pty_size(ssh_channel channel, const char *term, int cols, int rows):&#160;channels.c'],['../group__libssh__channel.html#gabb175414352256e1602286e0ab50886c',1,'ssh_channel_request_pty_size(ssh_channel channel, const char *terminal, int col, int row):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fsend_5fbreak',['ssh_channel_request_send_break',['../group__libssh__channel.html#gaef198ad0dcf0968aa2a449c8898d985e',1,'ssh_channel_request_send_break(ssh_channel channel, uint32_t length):&#160;channels.c'],['../group__libssh__channel.html#gaef198ad0dcf0968aa2a449c8898d985e',1,'ssh_channel_request_send_break(ssh_channel channel, uint32_t length):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fsend_5fsignal',['ssh_channel_request_send_signal',['../group__libssh__channel.html#gaa98315fca818b561970a6950683f4053',1,'ssh_channel_request_send_signal(ssh_channel channel, const char *signum):&#160;channels.c'],['../group__libssh__channel.html#gaa98315fca818b561970a6950683f4053',1,'ssh_channel_request_send_signal(ssh_channel channel, const char *sig):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fshell',['ssh_channel_request_shell',['../group__libssh__channel.html#gaed4c5fb30c9df2b2548421ccf4e81bf1',1,'ssh_channel_request_shell(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gaed4c5fb30c9df2b2548421ccf4e81bf1',1,'ssh_channel_request_shell(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fsubsystem',['ssh_channel_request_subsystem',['../group__libssh__channel.html#ga06024b070f9b2a3d6964b79ae36695b7',1,'ssh_channel_request_subsystem(ssh_channel channel, const char *subsystem):&#160;channels.c'],['../group__libssh__channel.html#ga06024b070f9b2a3d6964b79ae36695b7',1,'ssh_channel_request_subsystem(ssh_channel channel, const char *subsys):&#160;channels.c']]],
  ['ssh_5fchannel_5frequest_5fx11',['ssh_channel_request_x11',['../group__libssh__channel.html#gadfa34624c28164bd73453cd04aa64c1f',1,'ssh_channel_request_x11(ssh_channel channel, int single_connection, const char *protocol, const char *cookie, int screen_number):&#160;channels.c'],['../group__libssh__channel.html#gadfa34624c28164bd73453cd04aa64c1f',1,'ssh_channel_request_x11(ssh_channel channel, int single_connection, const char *protocol, const char *cookie, int screen_number):&#160;channels.c']]],
  ['ssh_5fchannel_5fselect',['ssh_channel_select',['../group__libssh__channel.html#ga1026cfa48ecfc0b4898d4ea443acfc5d',1,'ssh_channel_select(ssh_channel *readchans, ssh_channel *writechans, ssh_channel *exceptchans, struct timeval *timeout):&#160;channels.c'],['../group__libssh__channel.html#ga1026cfa48ecfc0b4898d4ea443acfc5d',1,'ssh_channel_select(ssh_channel *readchans, ssh_channel *writechans, ssh_channel *exceptchans, struct timeval *timeout):&#160;channels.c']]],
  ['ssh_5fchannel_5fsend_5feof',['ssh_channel_send_eof',['../group__libssh__channel.html#ga072f82fdf3e50514f747653af2c99004',1,'ssh_channel_send_eof(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#ga072f82fdf3e50514f747653af2c99004',1,'ssh_channel_send_eof(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fset_5fblocking',['ssh_channel_set_blocking',['../group__libssh__channel.html#ga1c00ed18679d9a8c5b971260b5df13a2',1,'ssh_channel_set_blocking(ssh_channel channel, int blocking):&#160;channels.c'],['../group__libssh__channel.html#ga1c00ed18679d9a8c5b971260b5df13a2',1,'ssh_channel_set_blocking(ssh_channel channel, int blocking):&#160;channels.c']]],
  ['ssh_5fchannel_5fset_5fcounter',['ssh_channel_set_counter',['../group__libssh__channel.html#gab0649fe21b7a900b4a8e10ecb3401395',1,'ssh_channel_set_counter(ssh_channel channel, ssh_counter counter):&#160;channels.c'],['../group__libssh__channel.html#gab0649fe21b7a900b4a8e10ecb3401395',1,'ssh_channel_set_counter(ssh_channel channel, ssh_counter counter):&#160;channels.c']]],
  ['ssh_5fchannel_5fwindow_5fsize',['ssh_channel_window_size',['../group__libssh__channel.html#gadf53c5a5b501086af26d06cba3f1491f',1,'ssh_channel_window_size(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gadf53c5a5b501086af26d06cba3f1491f',1,'ssh_channel_window_size(ssh_channel channel):&#160;channels.c']]],
  ['ssh_5fchannel_5fwrite',['ssh_channel_write',['../group__libssh__channel.html#ga5d658df773ba854b35ff9f905341e2fb',1,'ssh_channel_write(ssh_channel channel, const void *data, uint32_t len):&#160;channels.c'],['../group__libssh__channel.html#ga5d658df773ba854b35ff9f905341e2fb',1,'ssh_channel_write(ssh_channel channel, const void *data, uint32_t len):&#160;channels.c']]],
  ['ssh_5fchannel_5fwrite_5fstderr',['ssh_channel_write_stderr',['../group__libssh__channel.html#ga7ebd0ed490ee4485c6d5feb7d22bc162',1,'ssh_channel_write_stderr(ssh_channel channel, const void *data, uint32_t len):&#160;channels.c'],['../group__libssh__channel.html#ga7ebd0ed490ee4485c6d5feb7d22bc162',1,'ssh_channel_write_stderr(ssh_channel channel, const void *data, uint32_t len):&#160;channels.c']]],
  ['ssh_5fclean_5fpubkey_5fhash',['ssh_clean_pubkey_hash',['../group__libssh__session.html#ga07827fd70a51ddc4030364f220eb4c9c',1,'ssh_clean_pubkey_hash(unsigned char **hash):&#160;dh.c'],['../group__libssh__session.html#ga07827fd70a51ddc4030364f220eb4c9c',1,'ssh_clean_pubkey_hash(unsigned char **hash):&#160;dh.c']]],
  ['ssh_5fconnect',['ssh_connect',['../group__libssh__session.html#ga032e07cbd8bc3f14cb2dd375db0b03d7',1,'ssh_connect(ssh_session session):&#160;client.c'],['../group__libssh__session.html#ga032e07cbd8bc3f14cb2dd375db0b03d7',1,'ssh_connect(ssh_session session):&#160;client.c']]],
  ['ssh_5fdirname',['ssh_dirname',['../group__libssh__misc.html#gad36f0f8dbde59aefedd385dff76384fa',1,'ssh_dirname(const char *path):&#160;misc.c'],['../group__libssh__misc.html#gad36f0f8dbde59aefedd385dff76384fa',1,'ssh_dirname(const char *path):&#160;misc.c']]],
  ['ssh_5fdisconnect',['ssh_disconnect',['../group__libssh__session.html#ga0f048a4c0dbe02cfb7e9c5b6d0db0f27',1,'ssh_disconnect(ssh_session session):&#160;client.c'],['../group__libssh__session.html#ga0f048a4c0dbe02cfb7e9c5b6d0db0f27',1,'ssh_disconnect(ssh_session session):&#160;client.c']]],
  ['ssh_5fdump_5fknownhost',['ssh_dump_knownhost',['../group__libssh__session.html#ga16eb5c500a1beaf18821c6ce51b7b965',1,'ssh_dump_knownhost(ssh_session session):&#160;known_hosts.c'],['../group__libssh__session.html#ga16eb5c500a1beaf18821c6ce51b7b965',1,'ssh_dump_knownhost(ssh_session session):&#160;known_hosts.c']]],
  ['ssh_5fevent_5fadd_5fconnector',['ssh_event_add_connector',['../group__libssh__poll.html#gae1f53a6ce420a41ae06ffb962f477f99',1,'ssh_event_add_connector(ssh_event event, ssh_connector connector):&#160;poll.c'],['../group__libssh__poll.html#gae1f53a6ce420a41ae06ffb962f477f99',1,'ssh_event_add_connector(ssh_event event, ssh_connector connector):&#160;poll.c']]],
  ['ssh_5fevent_5fadd_5ffd',['ssh_event_add_fd',['../group__libssh__poll.html#ga41d63ffe950a48e8b2c513877e0cd6b4',1,'ssh_event_add_fd(ssh_event event, socket_t fd, short events, ssh_event_callback cb, void *userdata):&#160;poll.c'],['../group__libssh__poll.html#ga41d63ffe950a48e8b2c513877e0cd6b4',1,'ssh_event_add_fd(ssh_event event, socket_t fd, short events, ssh_event_callback cb, void *userdata):&#160;poll.c']]],
  ['ssh_5fevent_5fadd_5fpoll',['ssh_event_add_poll',['../group__libssh__poll.html#gaaf3e1df762650369e99595eee761f2a9',1,'ssh_event_add_poll(ssh_event event, ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#gaaf3e1df762650369e99595eee761f2a9',1,'ssh_event_add_poll(ssh_event event, ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fevent_5fadd_5fsession',['ssh_event_add_session',['../group__libssh__poll.html#ga51af38de4cc3adbd5566ec1f1b91983d',1,'ssh_event_add_session(ssh_event event, ssh_session session):&#160;poll.c'],['../group__libssh__poll.html#ga51af38de4cc3adbd5566ec1f1b91983d',1,'ssh_event_add_session(ssh_event event, ssh_session session):&#160;poll.c']]],
  ['ssh_5fevent_5fdopoll',['ssh_event_dopoll',['../group__libssh__poll.html#gada90c0ca6919271708ba1ea0352632cb',1,'ssh_event_dopoll(ssh_event event, int timeout):&#160;poll.c'],['../group__libssh__poll.html#gada90c0ca6919271708ba1ea0352632cb',1,'ssh_event_dopoll(ssh_event event, int timeout):&#160;poll.c']]],
  ['ssh_5fevent_5ffree',['ssh_event_free',['../group__libssh__poll.html#ga101388903c74d53ed550574b587449cd',1,'ssh_event_free(ssh_event event):&#160;poll.c'],['../group__libssh__poll.html#ga101388903c74d53ed550574b587449cd',1,'ssh_event_free(ssh_event event):&#160;poll.c']]],
  ['ssh_5fevent_5fnew',['ssh_event_new',['../group__libssh__poll.html#ga406895f99b6b486c4b65536e5399ff96',1,'ssh_event_new(void):&#160;poll.c'],['../group__libssh__poll.html#ga406895f99b6b486c4b65536e5399ff96',1,'ssh_event_new(void):&#160;poll.c']]],
  ['ssh_5fevent_5fremove_5fconnector',['ssh_event_remove_connector',['../group__libssh__poll.html#gae120116df5a1da09ee9edd42e6a63397',1,'ssh_event_remove_connector(ssh_event event, ssh_connector connector):&#160;poll.c'],['../group__libssh__poll.html#gae120116df5a1da09ee9edd42e6a63397',1,'ssh_event_remove_connector(ssh_event event, ssh_connector connector):&#160;poll.c']]],
  ['ssh_5fevent_5fremove_5ffd',['ssh_event_remove_fd',['../group__libssh__poll.html#gaf2cdca09a3a2024ed9bb4f134c8ae368',1,'ssh_event_remove_fd(ssh_event event, socket_t fd):&#160;poll.c'],['../group__libssh__poll.html#gaf2cdca09a3a2024ed9bb4f134c8ae368',1,'ssh_event_remove_fd(ssh_event event, socket_t fd):&#160;poll.c']]],
  ['ssh_5fevent_5fremove_5fpoll',['ssh_event_remove_poll',['../group__libssh__poll.html#ga302e3942e697063f1a54319667231f73',1,'ssh_event_remove_poll(ssh_event event, ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#ga302e3942e697063f1a54319667231f73',1,'ssh_event_remove_poll(ssh_event event, ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fevent_5fremove_5fsession',['ssh_event_remove_session',['../group__libssh__poll.html#gaab8dec05a0afb49392c63b2ec158ac3d',1,'ssh_event_remove_session(ssh_event event, ssh_session session):&#160;poll.c'],['../group__libssh__poll.html#gaab8dec05a0afb49392c63b2ec158ac3d',1,'ssh_event_remove_session(ssh_event event, ssh_session session):&#160;poll.c']]],
  ['ssh_5ffinalize',['ssh_finalize',['../group__libssh.html#ga94a851d00248acde9cd7da084b491242',1,'ssh_finalize(void):&#160;init.c'],['../group__libssh.html#ga94a851d00248acde9cd7da084b491242',1,'ssh_finalize(void):&#160;init.c']]],
  ['ssh_5ffree',['ssh_free',['../group__libssh__session.html#gae5af27a98a7488e9f5ded6b37c274156',1,'ssh_free(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gae5af27a98a7488e9f5ded6b37c274156',1,'ssh_free(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fcipher_5fin',['ssh_get_cipher_in',['../group__libssh__session.html#ga81d8525f77c58d93ed0d320c38e62009',1,'ssh_get_cipher_in(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga81d8525f77c58d93ed0d320c38e62009',1,'ssh_get_cipher_in(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fcipher_5fout',['ssh_get_cipher_out',['../group__libssh__session.html#ga0a0b33868aec5337ba1d9aee8fee26d1',1,'ssh_get_cipher_out(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga0a0b33868aec5337ba1d9aee8fee26d1',1,'ssh_get_cipher_out(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fclientbanner',['ssh_get_clientbanner',['../group__libssh__session.html#ga1e76a1fc03d1d16fb59b0bd5e9978aa0',1,'ssh_get_clientbanner(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga1e76a1fc03d1d16fb59b0bd5e9978aa0',1,'ssh_get_clientbanner(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fdisconnect_5fmessage',['ssh_get_disconnect_message',['../group__libssh__session.html#gad19e368e35d48e02ba95970a7d1e87f5',1,'ssh_get_disconnect_message(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gad19e368e35d48e02ba95970a7d1e87f5',1,'ssh_get_disconnect_message(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5ferror',['ssh_get_error',['../group__libssh__error.html#ga9241586665bf21f823806473fc386258',1,'ssh_get_error(void *error):&#160;error.c'],['../group__libssh__error.html#ga9241586665bf21f823806473fc386258',1,'ssh_get_error(void *error):&#160;error.c']]],
  ['ssh_5fget_5ferror_5fcode',['ssh_get_error_code',['../group__libssh__error.html#ga036433b7bf3d4ca94206253f58d136f9',1,'ssh_get_error_code(void *error):&#160;error.c'],['../group__libssh__error.html#ga036433b7bf3d4ca94206253f58d136f9',1,'ssh_get_error_code(void *error):&#160;error.c']]],
  ['ssh_5fget_5ffd',['ssh_get_fd',['../group__libssh__session.html#gafe509fcea47714b5cd277d1e35e83276',1,'ssh_get_fd(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gafe509fcea47714b5cd277d1e35e83276',1,'ssh_get_fd(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5ffingerprint_5fhash',['ssh_get_fingerprint_hash',['../group__libssh__session.html#ga775072dc331a11b575957fe23fdd311b',1,'ssh_get_fingerprint_hash(enum ssh_publickey_hash_type type, unsigned char *hash, size_t len):&#160;dh.c'],['../group__libssh__session.html#ga775072dc331a11b575957fe23fdd311b',1,'ssh_get_fingerprint_hash(enum ssh_publickey_hash_type type, unsigned char *hash, size_t len):&#160;dh.c']]],
  ['ssh_5fget_5fhexa',['ssh_get_hexa',['../group__libssh__session.html#ga6ebcfc53884fdc5afb1607c94f8007d4',1,'ssh_get_hexa(const unsigned char *what, size_t len):&#160;dh.c'],['../group__libssh__session.html#ga6ebcfc53884fdc5afb1607c94f8007d4',1,'ssh_get_hexa(const unsigned char *what, size_t len):&#160;dh.c']]],
  ['ssh_5fget_5fhmac_5fin',['ssh_get_hmac_in',['../group__libssh__session.html#ga293196b7f1b1653ff970b8206671def9',1,'ssh_get_hmac_in(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga293196b7f1b1653ff970b8206671def9',1,'ssh_get_hmac_in(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fhmac_5fout',['ssh_get_hmac_out',['../group__libssh__session.html#ga2fc37631d6a350d9c31dcb336b98a836',1,'ssh_get_hmac_out(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga2fc37631d6a350d9c31dcb336b98a836',1,'ssh_get_hmac_out(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fissue_5fbanner',['ssh_get_issue_banner',['../group__libssh__session.html#ga89864d4d5cc6d3d6ef1c39652f2a688f',1,'ssh_get_issue_banner(ssh_session session):&#160;client.c'],['../group__libssh__session.html#ga89864d4d5cc6d3d6ef1c39652f2a688f',1,'ssh_get_issue_banner(ssh_session session):&#160;client.c']]],
  ['ssh_5fget_5fkex_5falgo',['ssh_get_kex_algo',['../group__libssh__session.html#ga3870bf9e03a2ac470ab202424224b15e',1,'ssh_get_kex_algo(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga3870bf9e03a2ac470ab202424224b15e',1,'ssh_get_kex_algo(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5flog_5fcallback',['ssh_get_log_callback',['../group__libssh__log.html#ga0f795c820547d058dbbfa80cd4fe9a4e',1,'ssh_get_log_callback(void):&#160;log.c'],['../group__libssh__log.html#ga0f795c820547d058dbbfa80cd4fe9a4e',1,'ssh_get_log_callback(void):&#160;log.c']]],
  ['ssh_5fget_5flog_5flevel',['ssh_get_log_level',['../group__libssh__log.html#gad6a0b7b581b12be4e34a110b7312614b',1,'ssh_get_log_level(void):&#160;log.c'],['../group__libssh__log.html#gad6a0b7b581b12be4e34a110b7312614b',1,'ssh_get_log_level(void):&#160;log.c']]],
  ['ssh_5fget_5flog_5fuserdata',['ssh_get_log_userdata',['../group__libssh__log.html#ga887a1e754cd935b55fea1afb1f718761',1,'ssh_get_log_userdata(void):&#160;log.c'],['../group__libssh__log.html#ga887a1e754cd935b55fea1afb1f718761',1,'ssh_get_log_userdata(void):&#160;log.c']]],
  ['ssh_5fget_5fopenssh_5fversion',['ssh_get_openssh_version',['../group__libssh__session.html#gac55d2895467a1e898ee75b4710d836a5',1,'ssh_get_openssh_version(ssh_session session):&#160;client.c'],['../group__libssh__session.html#gac55d2895467a1e898ee75b4710d836a5',1,'ssh_get_openssh_version(ssh_session session):&#160;client.c']]],
  ['ssh_5fget_5fpoll_5fflags',['ssh_get_poll_flags',['../group__libssh__session.html#gae9d0104fbeca17bcfb0659ad718c4606',1,'ssh_get_poll_flags(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gae9d0104fbeca17bcfb0659ad718c4606',1,'ssh_get_poll_flags(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fpubkey_5fhash',['ssh_get_pubkey_hash',['../group__libssh__session.html#gaf8ff0e2236d54d964a82f68d7323a741',1,'ssh_get_pubkey_hash(ssh_session session, unsigned char **hash):&#160;dh.c'],['../group__libssh__session.html#gaf8ff0e2236d54d964a82f68d7323a741',1,'ssh_get_pubkey_hash(ssh_session session, unsigned char **hash):&#160;dh.c']]],
  ['ssh_5fget_5fpublickey',['ssh_get_publickey',['../group__libssh__session.html#ga839a93298aeff85adbaf4db815b58730',1,'ssh_get_publickey(ssh_session session, ssh_key *key):&#160;dh.c'],['../group__libssh__session.html#ga839a93298aeff85adbaf4db815b58730',1,'ssh_get_publickey(ssh_session session, ssh_key *key):&#160;dh.c']]],
  ['ssh_5fget_5fpublickey_5fhash',['ssh_get_publickey_hash',['../group__libssh__session.html#ga7a7b16a4bed6d8d58f10bdb269172ff7',1,'ssh_get_publickey_hash(const ssh_key key, enum ssh_publickey_hash_type type, unsigned char **hash, size_t *hlen):&#160;dh.c'],['../group__libssh__session.html#ga7a7b16a4bed6d8d58f10bdb269172ff7',1,'ssh_get_publickey_hash(const ssh_key key, enum ssh_publickey_hash_type type, unsigned char **hash, size_t *hlen):&#160;dh.c']]],
  ['ssh_5fget_5fserver_5fpublickey',['ssh_get_server_publickey',['../group__libssh__session.html#ga5342eefee0497636e9657c968e106782',1,'ssh_get_server_publickey(ssh_session session, ssh_key *key):&#160;dh.c'],['../group__libssh__session.html#ga5342eefee0497636e9657c968e106782',1,'ssh_get_server_publickey(ssh_session session, ssh_key *key):&#160;dh.c']]],
  ['ssh_5fget_5fserverbanner',['ssh_get_serverbanner',['../group__libssh__session.html#gac89bcc9f438d031a32260926b04ea6b9',1,'ssh_get_serverbanner(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gac89bcc9f438d031a32260926b04ea6b9',1,'ssh_get_serverbanner(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fstatus',['ssh_get_status',['../group__libssh__session.html#gac199314d1646372c566ef14b9b6dca53',1,'ssh_get_status(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gac199314d1646372c566ef14b9b6dca53',1,'ssh_get_status(ssh_session session):&#160;session.c']]],
  ['ssh_5fget_5fversion',['ssh_get_version',['../group__libssh__session.html#ga8467735e4735165336f68ee82e24de0e',1,'ssh_get_version(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga8467735e4735165336f68ee82e24de0e',1,'ssh_get_version(ssh_session session):&#160;session.c']]],
  ['ssh_5fgetpass',['ssh_getpass',['../group__libssh__misc.html#gad6effc9fcc3529ae5d7301fb096aa71c',1,'ssh_getpass(const char *prompt, char *buf, size_t len, int echo, int verify):&#160;getpass.c'],['../group__libssh__misc.html#gad6effc9fcc3529ae5d7301fb096aa71c',1,'ssh_getpass(const char *prompt, char *buf, size_t len, int echo, int verify):&#160;getpass.c']]],
  ['ssh_5fhandle_5fkey_5fexchange',['ssh_handle_key_exchange',['../group__libssh__server.html#gab60c37350653eb3b65a99ac089c55830',1,'server.c']]],
  ['ssh_5finit',['ssh_init',['../group__libssh.html#ga3ebf8d6920e563f3b032e3cd5277598e',1,'ssh_init(void):&#160;init.c'],['../group__libssh.html#ga3ebf8d6920e563f3b032e3cd5277598e',1,'ssh_init(void):&#160;init.c']]],
  ['ssh_5fis_5fblocking',['ssh_is_blocking',['../group__libssh__session.html#ga0c959bde817801ac5de2db1e64b52f26',1,'ssh_is_blocking(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga0c959bde817801ac5de2db1e64b52f26',1,'ssh_is_blocking(ssh_session session):&#160;session.c']]],
  ['ssh_5fis_5fconnected',['ssh_is_connected',['../group__libssh__session.html#ga49d8f413a3c7879070a112703de1d6e2',1,'ssh_is_connected(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga49d8f413a3c7879070a112703de1d6e2',1,'ssh_is_connected(ssh_session session):&#160;session.c']]],
  ['ssh_5fis_5fserver_5fknown',['ssh_is_server_known',['../group__libssh__session.html#ga6f37e3d7bb6b938b44d6a34a76fdfa0b',1,'ssh_is_server_known(ssh_session session):&#160;known_hosts.c'],['../group__libssh__session.html#ga6f37e3d7bb6b938b44d6a34a76fdfa0b',1,'ssh_is_server_known(ssh_session session):&#160;known_hosts.c']]],
  ['ssh_5fkey_5falgorithm_5fallowed',['ssh_key_algorithm_allowed',['../group__libssh__pki.html#ga79010baa7b7ca9d4467910ff863e669d',1,'ssh_key_algorithm_allowed(ssh_session session, const char *type):&#160;pki.c'],['../group__libssh__pki.html#ga79010baa7b7ca9d4467910ff863e669d',1,'ssh_key_algorithm_allowed(ssh_session session, const char *type):&#160;pki.c']]],
  ['ssh_5fkey_5fclean',['ssh_key_clean',['../group__libssh__pki.html#ga9ee6aacb86cb7f4e8f3b5ec582040d3a',1,'ssh_key_clean(ssh_key key):&#160;pki.c'],['../group__libssh__pki.html#ga9ee6aacb86cb7f4e8f3b5ec582040d3a',1,'ssh_key_clean(ssh_key key):&#160;pki.c']]],
  ['ssh_5fkey_5fcmp',['ssh_key_cmp',['../group__libssh__pki.html#ga4dc33945294c2bbd671365a9d3db8e2f',1,'ssh_key_cmp(const ssh_key k1, const ssh_key k2, enum ssh_keycmp_e what):&#160;pki.c'],['../group__libssh__pki.html#ga4dc33945294c2bbd671365a9d3db8e2f',1,'ssh_key_cmp(const ssh_key k1, const ssh_key k2, enum ssh_keycmp_e what):&#160;pki.c']]],
  ['ssh_5fkey_5ffree',['ssh_key_free',['../group__libssh__pki.html#ga08808beb83a42ccd6f1c710ddeb1b4c2',1,'ssh_key_free(ssh_key key):&#160;pki.c'],['../group__libssh__pki.html#ga08808beb83a42ccd6f1c710ddeb1b4c2',1,'ssh_key_free(ssh_key key):&#160;pki.c']]],
  ['ssh_5fkey_5fget_5fsignature_5falgorithm',['ssh_key_get_signature_algorithm',['../group__libssh__pki.html#ga7ad4109947adef7dbe7f9b8d1577cc88',1,'ssh_key_get_signature_algorithm(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c'],['../group__libssh__pki.html#ga7ad4109947adef7dbe7f9b8d1577cc88',1,'ssh_key_get_signature_algorithm(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c']]],
  ['ssh_5fkey_5fis_5fprivate',['ssh_key_is_private',['../group__libssh__pki.html#ga09de68aba0a7c4e31d8ba7df43b637c5',1,'ssh_key_is_private(const ssh_key k):&#160;pki.c'],['../group__libssh__pki.html#ga09de68aba0a7c4e31d8ba7df43b637c5',1,'ssh_key_is_private(const ssh_key k):&#160;pki.c']]],
  ['ssh_5fkey_5fis_5fpublic',['ssh_key_is_public',['../group__libssh__pki.html#ga9bc688b5cbc400320ac44896eba21924',1,'ssh_key_is_public(const ssh_key k):&#160;pki.c'],['../group__libssh__pki.html#ga9bc688b5cbc400320ac44896eba21924',1,'ssh_key_is_public(const ssh_key k):&#160;pki.c']]],
  ['ssh_5fkey_5fnew',['ssh_key_new',['../group__libssh__pki.html#gabfebce03474a4d014aa779d5dbf057b0',1,'ssh_key_new(void):&#160;pki.c'],['../group__libssh__pki.html#gabfebce03474a4d014aa779d5dbf057b0',1,'ssh_key_new(void):&#160;pki.c']]],
  ['ssh_5fkey_5fsignature_5fto_5fchar',['ssh_key_signature_to_char',['../group__libssh__pki.html#ga6636345a73f0ccbc1a7dd722c5cad557',1,'ssh_key_signature_to_char(enum ssh_keytypes_e type, enum ssh_digest_e hash_type):&#160;pki.c'],['../group__libssh__pki.html#ga6636345a73f0ccbc1a7dd722c5cad557',1,'ssh_key_signature_to_char(enum ssh_keytypes_e type, enum ssh_digest_e hash_type):&#160;pki.c']]],
  ['ssh_5fkey_5ftype',['ssh_key_type',['../group__libssh__pki.html#ga9cb4a857f8e510f80cfc38e46c476490',1,'ssh_key_type(const ssh_key key):&#160;pki.c'],['../group__libssh__pki.html#ga9cb4a857f8e510f80cfc38e46c476490',1,'ssh_key_type(const ssh_key key):&#160;pki.c']]],
  ['ssh_5fkey_5ftype_5ffrom_5fname',['ssh_key_type_from_name',['../group__libssh__pki.html#ga44584f2316c6ccd40e9939454335d8bc',1,'ssh_key_type_from_name(const char *name):&#160;pki.c'],['../group__libssh__pki.html#ga44584f2316c6ccd40e9939454335d8bc',1,'ssh_key_type_from_name(const char *name):&#160;pki.c']]],
  ['ssh_5fkey_5ftype_5ffrom_5fsignature_5fname',['ssh_key_type_from_signature_name',['../group__libssh__pki.html#ga2ef2751330c2bd09f68a14adba6b37d5',1,'ssh_key_type_from_signature_name(const char *name):&#160;pki.c'],['../group__libssh__pki.html#ga2ef2751330c2bd09f68a14adba6b37d5',1,'ssh_key_type_from_signature_name(const char *name):&#160;pki.c']]],
  ['ssh_5fkey_5ftype_5fto_5fchar',['ssh_key_type_to_char',['../group__libssh__pki.html#ga302919f046a4af504e5a2a9924b031c1',1,'ssh_key_type_to_char(enum ssh_keytypes_e type):&#160;pki.c'],['../group__libssh__pki.html#ga302919f046a4af504e5a2a9924b031c1',1,'ssh_key_type_to_char(enum ssh_keytypes_e type):&#160;pki.c']]],
  ['ssh_5fkey_5ftype_5fto_5fhash',['ssh_key_type_to_hash',['../group__libssh__pki.html#ga10eb6e34355baea3a0dd8431188ca790',1,'ssh_key_type_to_hash(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c'],['../group__libssh__pki.html#ga10eb6e34355baea3a0dd8431188ca790',1,'ssh_key_type_to_hash(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c']]],
  ['ssh_5fknown_5fhosts_5fparse_5fline',['ssh_known_hosts_parse_line',['../group__libssh__session.html#gaa3a37302850d0467f19db4eba5257d3d',1,'ssh_known_hosts_parse_line(const char *host, const char *line, struct ssh_knownhosts_entry **entry):&#160;knownhosts.c'],['../group__libssh__session.html#gaa3a37302850d0467f19db4eba5257d3d',1,'ssh_known_hosts_parse_line(const char *hostname, const char *line, struct ssh_knownhosts_entry **entry):&#160;knownhosts.c']]],
  ['ssh_5fknownhosts_5fentry_5ffree',['ssh_knownhosts_entry_free',['../group__libssh__session.html#ga97b827bd9eef76277e8420359e843cd8',1,'ssh_knownhosts_entry_free(struct ssh_knownhosts_entry *entry):&#160;knownhosts.c'],['../group__libssh__session.html#ga97b827bd9eef76277e8420359e843cd8',1,'ssh_knownhosts_entry_free(struct ssh_knownhosts_entry *entry):&#160;knownhosts.c']]],
  ['ssh_5flist_5fcount',['ssh_list_count',['../group__libssh__misc.html#ga5cd8838fe4ea4b06a2b6729cf89e2415',1,'ssh_list_count(const struct ssh_list *list):&#160;misc.c'],['../group__libssh__misc.html#ga5cd8838fe4ea4b06a2b6729cf89e2415',1,'ssh_list_count(const struct ssh_list *list):&#160;misc.c']]],
  ['ssh_5fmessage_5fauth_5fpassword',['ssh_message_auth_password',['../group__libssh__server.html#gab434b45d3f542ab24735bba6432de85d',1,'server.c']]],
  ['ssh_5fmessage_5fauth_5fpubkey',['ssh_message_auth_pubkey',['../group__libssh__server.html#ga97e909b1d89b4c4747eb5b80ac9fd215',1,'server.c']]],
  ['ssh_5fmessage_5fauth_5fuser',['ssh_message_auth_user',['../group__libssh__server.html#gad05353966b70d7f04a3b7aed07a817cc',1,'server.c']]],
  ['ssh_5fmessage_5ffree',['ssh_message_free',['../group__libssh__messages.html#ga9d1b1d2279c6be3539f2b630960759c3',1,'ssh_message_free(ssh_message msg):&#160;messages.c'],['../group__libssh__messages.html#ga9d1b1d2279c6be3539f2b630960759c3',1,'ssh_message_free(ssh_message msg):&#160;messages.c']]],
  ['ssh_5fmessage_5fget',['ssh_message_get',['../group__libssh__messages.html#ga8e536b6f1c824b7ca43d0e8f954b3bd4',1,'ssh_message_get(ssh_session session):&#160;messages.c'],['../group__libssh__messages.html#ga8e536b6f1c824b7ca43d0e8f954b3bd4',1,'ssh_message_get(ssh_session session):&#160;messages.c']]],
  ['ssh_5fmessage_5freply_5fdefault',['ssh_message_reply_default',['../group__libssh__server.html#ga6e78c8f369333289d245931deed92573',1,'server.c']]],
  ['ssh_5fmessage_5fsubtype',['ssh_message_subtype',['../group__libssh__messages.html#ga7aa19d51c443b779fe454f0be3c666d4',1,'ssh_message_subtype(ssh_message msg):&#160;messages.c'],['../group__libssh__messages.html#ga7aa19d51c443b779fe454f0be3c666d4',1,'ssh_message_subtype(ssh_message msg):&#160;messages.c']]],
  ['ssh_5fmessage_5ftype',['ssh_message_type',['../group__libssh__messages.html#ga20fc6e536f170b98c7d62ce3675d8cdb',1,'ssh_message_type(ssh_message msg):&#160;messages.c'],['../group__libssh__messages.html#ga20fc6e536f170b98c7d62ce3675d8cdb',1,'ssh_message_type(ssh_message msg):&#160;messages.c']]],
  ['ssh_5fmkdir',['ssh_mkdir',['../group__libssh__misc.html#ga5e15e93beecaef3af67d02b7ba55309f',1,'ssh_mkdir(const char *pathname, mode_t mode):&#160;misc.c'],['../group__libssh__misc.html#ga5e15e93beecaef3af67d02b7ba55309f',1,'ssh_mkdir(const char *pathname, mode_t mode):&#160;misc.c']]],
  ['ssh_5fnew',['ssh_new',['../group__libssh__session.html#gaadadc0f9601547c30db7c4d62017d32c',1,'ssh_new(void):&#160;session.c'],['../group__libssh__session.html#gaadadc0f9601547c30db7c4d62017d32c',1,'ssh_new(void):&#160;session.c']]],
  ['ssh_5foptions_5fcopy',['ssh_options_copy',['../group__libssh__session.html#gaead8cef1f39e785139bc510852ce1dff',1,'ssh_options_copy(ssh_session src, ssh_session *dest):&#160;options.c'],['../group__libssh__session.html#gaead8cef1f39e785139bc510852ce1dff',1,'ssh_options_copy(ssh_session src, ssh_session *dest):&#160;options.c']]],
  ['ssh_5foptions_5fget',['ssh_options_get',['../group__libssh__session.html#gaaa9d400920cad4d6e4a0fb09ff8c7b01',1,'ssh_options_get(ssh_session session, enum ssh_options_e type, char **value):&#160;options.c'],['../group__libssh__session.html#gaaa9d400920cad4d6e4a0fb09ff8c7b01',1,'ssh_options_get(ssh_session session, enum ssh_options_e type, char **value):&#160;options.c']]],
  ['ssh_5foptions_5fget_5fport',['ssh_options_get_port',['../group__libssh__session.html#gaa298d8445355420d80f2d968477ba86f',1,'ssh_options_get_port(ssh_session session, unsigned int *port_target):&#160;options.c'],['../group__libssh__session.html#gaa298d8445355420d80f2d968477ba86f',1,'ssh_options_get_port(ssh_session session, unsigned int *port_target):&#160;options.c']]],
  ['ssh_5foptions_5fgetopt',['ssh_options_getopt',['../group__libssh__session.html#ga93f7f7159893f3ce62c9b178724eff75',1,'ssh_options_getopt(ssh_session session, int *argcptr, char **argv):&#160;options.c'],['../group__libssh__session.html#ga93f7f7159893f3ce62c9b178724eff75',1,'ssh_options_getopt(ssh_session session, int *argcptr, char **argv):&#160;options.c']]],
  ['ssh_5foptions_5fparse_5fconfig',['ssh_options_parse_config',['../group__libssh__session.html#ga82371e723260c7572ea061edecc2e9f1',1,'ssh_options_parse_config(ssh_session session, const char *filename):&#160;options.c'],['../group__libssh__session.html#ga82371e723260c7572ea061edecc2e9f1',1,'ssh_options_parse_config(ssh_session session, const char *filename):&#160;options.c']]],
  ['ssh_5foptions_5fset',['ssh_options_set',['../group__libssh__session.html#ga7a801b85800baa3f4e16f5b47db0a73d',1,'ssh_options_set(ssh_session session, enum ssh_options_e type, const void *value):&#160;options.c'],['../group__libssh__session.html#ga7a801b85800baa3f4e16f5b47db0a73d',1,'ssh_options_set(ssh_session session, enum ssh_options_e type, const void *value):&#160;options.c']]],
  ['ssh_5fpath_5fexpand_5ftilde',['ssh_path_expand_tilde',['../group__libssh__misc.html#ga85622306848fd7e735d5843747f6eb28',1,'ssh_path_expand_tilde(const char *d):&#160;misc.c'],['../group__libssh__misc.html#ga85622306848fd7e735d5843747f6eb28',1,'ssh_path_expand_tilde(const char *d):&#160;misc.c']]],
  ['ssh_5fpki_5fcopy_5fcert_5fto_5fprivkey',['ssh_pki_copy_cert_to_privkey',['../group__libssh__pki.html#ga71432844d5d210d63a92acff86f91e90',1,'ssh_pki_copy_cert_to_privkey(const ssh_key cert_key, ssh_key privkey):&#160;pki.c'],['../group__libssh__pki.html#ga71432844d5d210d63a92acff86f91e90',1,'ssh_pki_copy_cert_to_privkey(const ssh_key certkey, ssh_key privkey):&#160;pki.c']]],
  ['ssh_5fpki_5fexport_5fprivkey_5fbase64',['ssh_pki_export_privkey_base64',['../group__libssh__pki.html#ga320970245fa4e3ab873888b581e13378',1,'ssh_pki_export_privkey_base64(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, char **b64_key):&#160;pki.c'],['../group__libssh__pki.html#ga320970245fa4e3ab873888b581e13378',1,'ssh_pki_export_privkey_base64(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, char **b64_key):&#160;pki.c']]],
  ['ssh_5fpki_5fexport_5fprivkey_5ffile',['ssh_pki_export_privkey_file',['../group__libssh__pki.html#ga3b294c44e2280c935cb0b82ede5c42ee',1,'ssh_pki_export_privkey_file(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, const char *filename):&#160;pki.c'],['../group__libssh__pki.html#ga3b294c44e2280c935cb0b82ede5c42ee',1,'ssh_pki_export_privkey_file(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, const char *filename):&#160;pki.c']]],
  ['ssh_5fpki_5fexport_5fprivkey_5fto_5fpubkey',['ssh_pki_export_privkey_to_pubkey',['../group__libssh__pki.html#ga5777bc537da6a447b2a9aa9eceff9877',1,'ssh_pki_export_privkey_to_pubkey(const ssh_key privkey, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#ga5777bc537da6a447b2a9aa9eceff9877',1,'ssh_pki_export_privkey_to_pubkey(const ssh_key privkey, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fexport_5fpubkey_5fbase64',['ssh_pki_export_pubkey_base64',['../group__libssh__pki.html#ga2caa40cbd9620e9f7e3e7ab654b256c5',1,'ssh_pki_export_pubkey_base64(const ssh_key key, char **b64_key):&#160;pki.c'],['../group__libssh__pki.html#ga2caa40cbd9620e9f7e3e7ab654b256c5',1,'ssh_pki_export_pubkey_base64(const ssh_key key, char **b64_key):&#160;pki.c']]],
  ['ssh_5fpki_5fgenerate',['ssh_pki_generate',['../group__libssh__pki.html#gae038fa1b34f9427c7ba84082a1a20bad',1,'ssh_pki_generate(enum ssh_keytypes_e type, int parameter, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#gae038fa1b34f9427c7ba84082a1a20bad',1,'ssh_pki_generate(enum ssh_keytypes_e type, int parameter, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fimport_5fcert_5fbase64',['ssh_pki_import_cert_base64',['../group__libssh__pki.html#ga78c1f26eac4345a56749b4e086d9fa28',1,'ssh_pki_import_cert_base64(const char *b64_cert, enum ssh_keytypes_e type, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#ga78c1f26eac4345a56749b4e086d9fa28',1,'ssh_pki_import_cert_base64(const char *b64_cert, enum ssh_keytypes_e type, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fimport_5fcert_5ffile',['ssh_pki_import_cert_file',['../group__libssh__pki.html#ga95cb20de349b935e9d997327674d7065',1,'ssh_pki_import_cert_file(const char *filename, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#ga95cb20de349b935e9d997327674d7065',1,'ssh_pki_import_cert_file(const char *filename, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fimport_5fprivkey_5fbase64',['ssh_pki_import_privkey_base64',['../group__libssh__pki.html#ga5f2a2ca4b9b711d1c1af8020dfbd4a53',1,'ssh_pki_import_privkey_base64(const char *b64_key, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#ga5f2a2ca4b9b711d1c1af8020dfbd4a53',1,'ssh_pki_import_privkey_base64(const char *b64_key, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fimport_5fprivkey_5ffile',['ssh_pki_import_privkey_file',['../group__libssh__pki.html#ga1c8f84137606b1585006302499100ee0',1,'ssh_pki_import_privkey_file(const char *filename, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#ga1c8f84137606b1585006302499100ee0',1,'ssh_pki_import_privkey_file(const char *filename, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fimport_5fpubkey_5fbase64',['ssh_pki_import_pubkey_base64',['../group__libssh__pki.html#gac8d7d3fa88b93d8b059b6b5b2f457913',1,'ssh_pki_import_pubkey_base64(const char *b64_key, enum ssh_keytypes_e type, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#gac8d7d3fa88b93d8b059b6b5b2f457913',1,'ssh_pki_import_pubkey_base64(const char *b64_key, enum ssh_keytypes_e type, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fimport_5fpubkey_5ffile',['ssh_pki_import_pubkey_file',['../group__libssh__pki.html#gaffb08168b870fb9e86cc7649c8987eb0',1,'ssh_pki_import_pubkey_file(const char *filename, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#gaffb08168b870fb9e86cc7649c8987eb0',1,'ssh_pki_import_pubkey_file(const char *filename, ssh_key *pkey):&#160;pki.c']]],
  ['ssh_5fpki_5fkey_5fecdsa_5fname',['ssh_pki_key_ecdsa_name',['../group__libssh__pki.html#gaf9ba4d3e3cd2a8b61fabe33b5b7e59c2',1,'ssh_pki_key_ecdsa_name(const ssh_key key):&#160;pki.c'],['../group__libssh__pki.html#gaf9ba4d3e3cd2a8b61fabe33b5b7e59c2',1,'ssh_pki_key_ecdsa_name(const ssh_key key):&#160;pki.c']]],
  ['ssh_5fpoll_5fadd_5fevents',['ssh_poll_add_events',['../group__libssh__poll.html#ga26ad689751420b91bf002f616e8bf4f7',1,'ssh_poll_add_events(ssh_poll_handle p, short events):&#160;poll.c'],['../group__libssh__poll.html#ga26ad689751420b91bf002f616e8bf4f7',1,'ssh_poll_add_events(ssh_poll_handle p, short events):&#160;poll.c']]],
  ['ssh_5fpoll_5fctx_5fadd',['ssh_poll_ctx_add',['../group__libssh__poll.html#ga2c9eca31ff21406f13c1b7472ae8c85b',1,'ssh_poll_ctx_add(ssh_poll_ctx ctx, ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#ga2c9eca31ff21406f13c1b7472ae8c85b',1,'ssh_poll_ctx_add(ssh_poll_ctx ctx, ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fpoll_5fctx_5fadd_5fsocket',['ssh_poll_ctx_add_socket',['../group__libssh__poll.html#ga4aa3ef276370adbb4afb284947dc8005',1,'poll.c']]],
  ['ssh_5fpoll_5fctx_5fdopoll',['ssh_poll_ctx_dopoll',['../group__libssh__poll.html#ga6c0f6d3c677838181df5cd03a755fd7c',1,'ssh_poll_ctx_dopoll(ssh_poll_ctx ctx, int timeout):&#160;poll.c'],['../group__libssh__poll.html#ga6c0f6d3c677838181df5cd03a755fd7c',1,'ssh_poll_ctx_dopoll(ssh_poll_ctx ctx, int timeout):&#160;poll.c']]],
  ['ssh_5fpoll_5fctx_5ffree',['ssh_poll_ctx_free',['../group__libssh__poll.html#ga86bd0c5c2fa5614acef127e6689282ae',1,'ssh_poll_ctx_free(ssh_poll_ctx ctx):&#160;poll.c'],['../group__libssh__poll.html#ga86bd0c5c2fa5614acef127e6689282ae',1,'ssh_poll_ctx_free(ssh_poll_ctx ctx):&#160;poll.c']]],
  ['ssh_5fpoll_5fctx_5fnew',['ssh_poll_ctx_new',['../group__libssh__poll.html#ga5364b3fb8ae1cb44e3ec09c8c10cb5fa',1,'ssh_poll_ctx_new(size_t chunk_size):&#160;poll.c'],['../group__libssh__poll.html#ga5364b3fb8ae1cb44e3ec09c8c10cb5fa',1,'ssh_poll_ctx_new(size_t chunk_size):&#160;poll.c']]],
  ['ssh_5fpoll_5fctx_5fremove',['ssh_poll_ctx_remove',['../group__libssh__poll.html#gad4404e7da7c676b126b87d2de4d45d1d',1,'ssh_poll_ctx_remove(ssh_poll_ctx ctx, ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#gad4404e7da7c676b126b87d2de4d45d1d',1,'ssh_poll_ctx_remove(ssh_poll_ctx ctx, ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fpoll_5ffree',['ssh_poll_free',['../group__libssh__poll.html#ga873ecc6866c286f7777612d94de5c00d',1,'ssh_poll_free(ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#ga873ecc6866c286f7777612d94de5c00d',1,'ssh_poll_free(ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fpoll_5fget_5fctx',['ssh_poll_get_ctx',['../group__libssh__poll.html#gaca05fcf77e6c4b5e55a9cfd2c9690ea5',1,'ssh_poll_get_ctx(ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#gaca05fcf77e6c4b5e55a9cfd2c9690ea5',1,'ssh_poll_get_ctx(ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fpoll_5fget_5fevents',['ssh_poll_get_events',['../group__libssh__poll.html#ga8e2e646ac338021e8e804992e8c13496',1,'ssh_poll_get_events(ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#ga8e2e646ac338021e8e804992e8c13496',1,'ssh_poll_get_events(ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fpoll_5fget_5ffd',['ssh_poll_get_fd',['../group__libssh__poll.html#ga26c19b17ac8d1e3d7fcbfb4367fb93ff',1,'ssh_poll_get_fd(ssh_poll_handle p):&#160;poll.c'],['../group__libssh__poll.html#ga26c19b17ac8d1e3d7fcbfb4367fb93ff',1,'ssh_poll_get_fd(ssh_poll_handle p):&#160;poll.c']]],
  ['ssh_5fpoll_5fnew',['ssh_poll_new',['../group__libssh__poll.html#gac657ed07db9e5851ffb0aba45e071e99',1,'ssh_poll_new(socket_t fd, short events, ssh_poll_callback cb, void *userdata):&#160;poll.c'],['../group__libssh__poll.html#gac657ed07db9e5851ffb0aba45e071e99',1,'ssh_poll_new(socket_t fd, short events, ssh_poll_callback cb, void *userdata):&#160;poll.c']]],
  ['ssh_5fpoll_5fremove_5fevents',['ssh_poll_remove_events',['../group__libssh__poll.html#ga012582349ce62cf788761e5f97548496',1,'ssh_poll_remove_events(ssh_poll_handle p, short events):&#160;poll.c'],['../group__libssh__poll.html#ga012582349ce62cf788761e5f97548496',1,'ssh_poll_remove_events(ssh_poll_handle p, short events):&#160;poll.c']]],
  ['ssh_5fpoll_5fset_5fcallback',['ssh_poll_set_callback',['../group__libssh__poll.html#ga98ba36c2771b1e49d5c8e2f79be6d3ba',1,'ssh_poll_set_callback(ssh_poll_handle p, ssh_poll_callback cb, void *userdata):&#160;poll.c'],['../group__libssh__poll.html#ga98ba36c2771b1e49d5c8e2f79be6d3ba',1,'ssh_poll_set_callback(ssh_poll_handle p, ssh_poll_callback cb, void *userdata):&#160;poll.c']]],
  ['ssh_5fpoll_5fset_5fevents',['ssh_poll_set_events',['../group__libssh__poll.html#gac02bf6f4444d4cc442da5865009fa5f6',1,'ssh_poll_set_events(ssh_poll_handle p, short events):&#160;poll.c'],['../group__libssh__poll.html#gac02bf6f4444d4cc442da5865009fa5f6',1,'ssh_poll_set_events(ssh_poll_handle p, short events):&#160;poll.c']]],
  ['ssh_5fpoll_5fset_5ffd',['ssh_poll_set_fd',['../group__libssh__poll.html#ga2da5adcc03754a3b17e4fb0f23867ace',1,'ssh_poll_set_fd(ssh_poll_handle p, socket_t fd):&#160;poll.c'],['../group__libssh__poll.html#ga2da5adcc03754a3b17e4fb0f23867ace',1,'ssh_poll_set_fd(ssh_poll_handle p, socket_t fd):&#160;poll.c']]],
  ['ssh_5fprint_5fhash',['ssh_print_hash',['../group__libssh__session.html#ga93e85883ddac5198ed590e36eef4dc3b',1,'ssh_print_hash(enum ssh_publickey_hash_type type, unsigned char *hash, size_t len):&#160;dh.c'],['../group__libssh__session.html#ga93e85883ddac5198ed590e36eef4dc3b',1,'ssh_print_hash(enum ssh_publickey_hash_type type, unsigned char *hash, size_t len):&#160;dh.c']]],
  ['ssh_5fprint_5fhexa',['ssh_print_hexa',['../group__libssh__session.html#ga39bf7936ed51361fe9cf3c3bbfc25514',1,'ssh_print_hexa(const char *descr, const unsigned char *what, size_t len):&#160;dh.c'],['../group__libssh__session.html#ga39bf7936ed51361fe9cf3c3bbfc25514',1,'ssh_print_hexa(const char *descr, const unsigned char *what, size_t len):&#160;dh.c']]],
  ['ssh_5fremove_5fchannel_5fcallbacks',['ssh_remove_channel_callbacks',['../group__libssh__callbacks.html#gae564352175e887c346a2e062f8124282',1,'ssh_remove_channel_callbacks(ssh_channel channel, ssh_channel_callbacks cb):&#160;callbacks.c'],['../group__libssh__callbacks.html#gae564352175e887c346a2e062f8124282',1,'ssh_remove_channel_callbacks(ssh_channel channel, ssh_channel_callbacks cb):&#160;callbacks.c']]],
  ['ssh_5fscp_5faccept_5frequest',['ssh_scp_accept_request',['../group__libssh__scp.html#gad3bb38b15f02597cc1e155c526a51e51',1,'ssh_scp_accept_request(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#gad3bb38b15f02597cc1e155c526a51e51',1,'ssh_scp_accept_request(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5fclose',['ssh_scp_close',['../group__libssh__scp.html#ga14d31059dcf6fb2325fb960da8e4474e',1,'ssh_scp_close(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#ga14d31059dcf6fb2325fb960da8e4474e',1,'ssh_scp_close(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5fdeny_5frequest',['ssh_scp_deny_request',['../group__libssh__scp.html#gad36438c6b1e235d96cec43ca350e9b4f',1,'ssh_scp_deny_request(ssh_scp scp, const char *reason):&#160;scp.c'],['../group__libssh__scp.html#gad36438c6b1e235d96cec43ca350e9b4f',1,'ssh_scp_deny_request(ssh_scp scp, const char *reason):&#160;scp.c']]],
  ['ssh_5fscp_5ffree',['ssh_scp_free',['../group__libssh__scp.html#gac29000cdb07c74d54251fbd838c0c661',1,'ssh_scp_free(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#gac29000cdb07c74d54251fbd838c0c661',1,'ssh_scp_free(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5finit',['ssh_scp_init',['../group__libssh__scp.html#ga1db56dcb9dee01dd0b679b3b11151110',1,'ssh_scp_init(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#ga1db56dcb9dee01dd0b679b3b11151110',1,'ssh_scp_init(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5finteger_5fmode',['ssh_scp_integer_mode',['../group__libssh__scp.html#gab7d6e452c6963199477103394456d3ae',1,'ssh_scp_integer_mode(const char *mode):&#160;scp.c'],['../group__libssh__scp.html#gab7d6e452c6963199477103394456d3ae',1,'ssh_scp_integer_mode(const char *mode):&#160;scp.c']]],
  ['ssh_5fscp_5fleave_5fdirectory',['ssh_scp_leave_directory',['../group__libssh__scp.html#ga2ca698c1e49612c083d9f8a72df52188',1,'ssh_scp_leave_directory(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#ga2ca698c1e49612c083d9f8a72df52188',1,'ssh_scp_leave_directory(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5fnew',['ssh_scp_new',['../group__libssh__scp.html#ga9fcd39a2bb6438e39cf19ff859dc2f2e',1,'ssh_scp_new(ssh_session session, int mode, const char *location):&#160;scp.c'],['../group__libssh__scp.html#ga9fcd39a2bb6438e39cf19ff859dc2f2e',1,'ssh_scp_new(ssh_session session, int mode, const char *location):&#160;scp.c']]],
  ['ssh_5fscp_5fpull_5frequest',['ssh_scp_pull_request',['../group__libssh__scp.html#gaba59cd8cc77d219cac93f865445c6e47',1,'ssh_scp_pull_request(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#gaba59cd8cc77d219cac93f865445c6e47',1,'ssh_scp_pull_request(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5fpush_5fdirectory',['ssh_scp_push_directory',['../group__libssh__scp.html#gaa584f03d4e3d582ac10a3a19818ec56d',1,'ssh_scp_push_directory(ssh_scp scp, const char *dirname, int mode):&#160;scp.c'],['../group__libssh__scp.html#gaa584f03d4e3d582ac10a3a19818ec56d',1,'ssh_scp_push_directory(ssh_scp scp, const char *dirname, int mode):&#160;scp.c']]],
  ['ssh_5fscp_5fpush_5ffile',['ssh_scp_push_file',['../group__libssh__scp.html#ga544f4b9c525071910110ada94148adc6',1,'ssh_scp_push_file(ssh_scp scp, const char *filename, size_t size, int perms):&#160;scp.c'],['../group__libssh__scp.html#ga544f4b9c525071910110ada94148adc6',1,'ssh_scp_push_file(ssh_scp scp, const char *filename, size_t size, int mode):&#160;scp.c']]],
  ['ssh_5fscp_5fpush_5ffile64',['ssh_scp_push_file64',['../group__libssh__scp.html#ga50b701b9c8923011d4fc6489c9c7eaae',1,'ssh_scp_push_file64(ssh_scp scp, const char *filename, uint64_t size, int perms):&#160;scp.c'],['../group__libssh__scp.html#ga50b701b9c8923011d4fc6489c9c7eaae',1,'ssh_scp_push_file64(ssh_scp scp, const char *filename, uint64_t size, int mode):&#160;scp.c']]],
  ['ssh_5fscp_5fread',['ssh_scp_read',['../group__libssh__scp.html#ga10bf627407959b51a7c39b37e8d46460',1,'ssh_scp_read(ssh_scp scp, void *buffer, size_t size):&#160;scp.c'],['../group__libssh__scp.html#ga10bf627407959b51a7c39b37e8d46460',1,'ssh_scp_read(ssh_scp scp, void *buffer, size_t size):&#160;scp.c']]],
  ['ssh_5fscp_5fread_5fstring',['ssh_scp_read_string',['../group__libssh__scp.html#ga0be44d8a450767d92668d36d1beb43b9',1,'ssh_scp_read_string(ssh_scp scp, char *buffer, size_t len):&#160;scp.c'],['../group__libssh__scp.html#ga0be44d8a450767d92668d36d1beb43b9',1,'ssh_scp_read_string(ssh_scp scp, char *buffer, size_t len):&#160;scp.c']]],
  ['ssh_5fscp_5frequest_5fget_5ffilename',['ssh_scp_request_get_filename',['../group__libssh__scp.html#gab41ede14208dea4bbd3600077008ccf3',1,'ssh_scp_request_get_filename(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#gab41ede14208dea4bbd3600077008ccf3',1,'ssh_scp_request_get_filename(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5frequest_5fget_5fpermissions',['ssh_scp_request_get_permissions',['../group__libssh__scp.html#ga3386eb6df0cc620e74a039974c6280d4',1,'ssh_scp_request_get_permissions(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#ga3386eb6df0cc620e74a039974c6280d4',1,'ssh_scp_request_get_permissions(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5frequest_5fget_5fsize',['ssh_scp_request_get_size',['../group__libssh__scp.html#ga8b6f736a5b5af73cf59c7825d7e61966',1,'ssh_scp_request_get_size(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#ga8b6f736a5b5af73cf59c7825d7e61966',1,'ssh_scp_request_get_size(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5frequest_5fget_5fsize64',['ssh_scp_request_get_size64',['../group__libssh__scp.html#gaefe7f44417e1dc0d857d634fe1117d6d',1,'ssh_scp_request_get_size64(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#gaefe7f44417e1dc0d857d634fe1117d6d',1,'ssh_scp_request_get_size64(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5frequest_5fget_5fwarning',['ssh_scp_request_get_warning',['../group__libssh__scp.html#gafa91c1569e4d22d58a928b232264bbcb',1,'ssh_scp_request_get_warning(ssh_scp scp):&#160;scp.c'],['../group__libssh__scp.html#gafa91c1569e4d22d58a928b232264bbcb',1,'ssh_scp_request_get_warning(ssh_scp scp):&#160;scp.c']]],
  ['ssh_5fscp_5fstring_5fmode',['ssh_scp_string_mode',['../group__libssh__scp.html#ga8772a6523a2a21a06e3986dbcc02118f',1,'ssh_scp_string_mode(int mode):&#160;scp.c'],['../group__libssh__scp.html#ga8772a6523a2a21a06e3986dbcc02118f',1,'ssh_scp_string_mode(int mode):&#160;scp.c']]],
  ['ssh_5fscp_5fwrite',['ssh_scp_write',['../group__libssh__scp.html#ga11f48e2cf62bcec20d9232ed3ca41752',1,'ssh_scp_write(ssh_scp scp, const void *buffer, size_t len):&#160;scp.c'],['../group__libssh__scp.html#ga11f48e2cf62bcec20d9232ed3ca41752',1,'ssh_scp_write(ssh_scp scp, const void *buffer, size_t len):&#160;scp.c']]],
  ['ssh_5fselect',['ssh_select',['../group__libssh__session.html#ga86cbf041bced56d18a2a5248c46cecb4',1,'ssh_select(ssh_channel *channels, ssh_channel *outchannels, socket_t maxfd, fd_set *readfds, struct timeval *timeout):&#160;connect.c'],['../group__libssh__session.html#ga86cbf041bced56d18a2a5248c46cecb4',1,'ssh_select(ssh_channel *channels, ssh_channel *outchannels, socket_t maxfd, fd_set *readfds, struct timeval *timeout):&#160;connect.c']]],
  ['ssh_5fsend_5fdebug',['ssh_send_debug',['../group__libssh__session.html#ga5ffa2201152e29cc680c4b8e4a3f4fdf',1,'ssh_send_debug(ssh_session session, const char *message, int always_display):&#160;session.c'],['../group__libssh__session.html#ga5ffa2201152e29cc680c4b8e4a3f4fdf',1,'ssh_send_debug(ssh_session session, const char *message, int always_display):&#160;session.c']]],
  ['ssh_5fsend_5fignore',['ssh_send_ignore',['../group__libssh__session.html#gab8827415fd19cf6cb64e7fc83c09e423',1,'ssh_send_ignore(ssh_session session, const char *data):&#160;session.c'],['../group__libssh__session.html#gab8827415fd19cf6cb64e7fc83c09e423',1,'ssh_send_ignore(ssh_session session, const char *data):&#160;session.c']]],
  ['ssh_5fserver_5finit_5fkex',['ssh_server_init_kex',['../group__libssh__server.html#ga2594833b600c8461fbe26d16e99a211b',1,'server.c']]],
  ['ssh_5fsession_5fexport_5fknown_5fhosts_5fentry',['ssh_session_export_known_hosts_entry',['../group__libssh__session.html#ga519c3985c8803c67d24ce9f937e3da9a',1,'ssh_session_export_known_hosts_entry(ssh_session session, char **pentry_string):&#160;knownhosts.c'],['../group__libssh__session.html#ga519c3985c8803c67d24ce9f937e3da9a',1,'ssh_session_export_known_hosts_entry(ssh_session session, char **pentry_string):&#160;knownhosts.c']]],
  ['ssh_5fsession_5fget_5fknown_5fhosts_5fentry',['ssh_session_get_known_hosts_entry',['../group__libssh__session.html#ga874d3246c9c9bfc7040302e10650bce8',1,'ssh_session_get_known_hosts_entry(ssh_session session, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c'],['../group__libssh__session.html#ga874d3246c9c9bfc7040302e10650bce8',1,'ssh_session_get_known_hosts_entry(ssh_session session, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c']]],
  ['ssh_5fsession_5fget_5fknown_5fhosts_5fentry_5ffile',['ssh_session_get_known_hosts_entry_file',['../group__libssh__session.html#gae484a2e6dac6c5738db62c3ba602f118',1,'ssh_session_get_known_hosts_entry_file(ssh_session session, const char *filename, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c'],['../group__libssh__session.html#gae484a2e6dac6c5738db62c3ba602f118',1,'ssh_session_get_known_hosts_entry_file(ssh_session session, const char *filename, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c']]],
  ['ssh_5fsession_5fhas_5fknown_5fhosts_5fentry',['ssh_session_has_known_hosts_entry',['../group__libssh__session.html#gaffea2fa1210919f833a081739734476d',1,'ssh_session_has_known_hosts_entry(ssh_session session):&#160;knownhosts.c'],['../group__libssh__session.html#gaffea2fa1210919f833a081739734476d',1,'ssh_session_has_known_hosts_entry(ssh_session session):&#160;knownhosts.c']]],
  ['ssh_5fsession_5fis_5fknown_5fserver',['ssh_session_is_known_server',['../group__libssh__session.html#gacbc5d04fe66beee863a0c61a93fdf765',1,'ssh_session_is_known_server(ssh_session session):&#160;knownhosts.c'],['../group__libssh__session.html#gacbc5d04fe66beee863a0c61a93fdf765',1,'ssh_session_is_known_server(ssh_session session):&#160;knownhosts.c']]],
  ['ssh_5fsession_5fupdate_5fknown_5fhosts',['ssh_session_update_known_hosts',['../group__libssh__session.html#ga958fdd1aedcd85a5c496c0aa22362d34',1,'ssh_session_update_known_hosts(ssh_session session):&#160;knownhosts.c'],['../group__libssh__session.html#ga958fdd1aedcd85a5c496c0aa22362d34',1,'ssh_session_update_known_hosts(ssh_session session):&#160;knownhosts.c']]],
  ['ssh_5fset_5fauth_5fmethods',['ssh_set_auth_methods',['../group__libssh__server.html#gabbfb96c938e33a8dddebaff29f25e0c6',1,'server.c']]],
  ['ssh_5fset_5fblocking',['ssh_set_blocking',['../group__libssh__session.html#ga2a29cff08855611be84d050e5bec73bc',1,'ssh_set_blocking(ssh_session session, int blocking):&#160;session.c'],['../group__libssh__session.html#ga2a29cff08855611be84d050e5bec73bc',1,'ssh_set_blocking(ssh_session session, int blocking):&#160;session.c']]],
  ['ssh_5fset_5fcallbacks',['ssh_set_callbacks',['../group__libssh__callbacks.html#ga2e4b0507c738748a3f10e43fe201fe09',1,'ssh_set_callbacks(ssh_session session, ssh_callbacks cb):&#160;callbacks.c'],['../group__libssh__callbacks.html#ga2e4b0507c738748a3f10e43fe201fe09',1,'ssh_set_callbacks(ssh_session session, ssh_callbacks cb):&#160;callbacks.c']]],
  ['ssh_5fset_5fchannel_5fcallbacks',['ssh_set_channel_callbacks',['../group__libssh__callbacks.html#gacea52d1373970a4922bf60e6b1680919',1,'ssh_set_channel_callbacks(ssh_channel channel, ssh_channel_callbacks cb):&#160;callbacks.c'],['../group__libssh__callbacks.html#gacea52d1373970a4922bf60e6b1680919',1,'ssh_set_channel_callbacks(ssh_channel channel, ssh_channel_callbacks cb):&#160;callbacks.c']]],
  ['ssh_5fset_5fcounters',['ssh_set_counters',['../group__libssh__session.html#ga84d4ac53ac8582b70da9b63739df61ad',1,'ssh_set_counters(ssh_session session, ssh_counter scounter, ssh_counter rcounter):&#160;session.c'],['../group__libssh__session.html#ga84d4ac53ac8582b70da9b63739df61ad',1,'ssh_set_counters(ssh_session session, ssh_counter scounter, ssh_counter rcounter):&#160;session.c']]],
  ['ssh_5fset_5ffd_5fexcept',['ssh_set_fd_except',['../group__libssh__session.html#ga06453278350fd9e940c5c1b0d5225f19',1,'ssh_set_fd_except(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga06453278350fd9e940c5c1b0d5225f19',1,'ssh_set_fd_except(ssh_session session):&#160;session.c']]],
  ['ssh_5fset_5ffd_5ftoread',['ssh_set_fd_toread',['../group__libssh__session.html#ga0e05c91c6f475eabc8d221914d25a425',1,'ssh_set_fd_toread(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga0e05c91c6f475eabc8d221914d25a425',1,'ssh_set_fd_toread(ssh_session session):&#160;session.c']]],
  ['ssh_5fset_5ffd_5ftowrite',['ssh_set_fd_towrite',['../group__libssh__session.html#ga3f1b3c59662464eec3649d3d72a40543',1,'ssh_set_fd_towrite(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga3f1b3c59662464eec3649d3d72a40543',1,'ssh_set_fd_towrite(ssh_session session):&#160;session.c']]],
  ['ssh_5fset_5flog_5fcallback',['ssh_set_log_callback',['../group__libssh__log.html#ga6accdc08b7d8c4234750ef30c4854b9e',1,'ssh_set_log_callback(ssh_logging_callback cb):&#160;log.c'],['../group__libssh__log.html#ga6accdc08b7d8c4234750ef30c4854b9e',1,'ssh_set_log_callback(ssh_logging_callback cb):&#160;log.c']]],
  ['ssh_5fset_5flog_5flevel',['ssh_set_log_level',['../group__libssh__log.html#ga9719dabb8fab8a3ebeb4dc2ebcd2dd45',1,'ssh_set_log_level(int level):&#160;log.c'],['../group__libssh__log.html#ga9719dabb8fab8a3ebeb4dc2ebcd2dd45',1,'ssh_set_log_level(int level):&#160;log.c']]],
  ['ssh_5fset_5flog_5fuserdata',['ssh_set_log_userdata',['../group__libssh__log.html#ga0addd5c29922f40e9f842a43e0cb0b27',1,'ssh_set_log_userdata(void *data):&#160;log.c'],['../group__libssh__log.html#ga0addd5c29922f40e9f842a43e0cb0b27',1,'ssh_set_log_userdata(void *data):&#160;log.c']]],
  ['ssh_5fset_5fmessage_5fcallback',['ssh_set_message_callback',['../group__libssh__server.html#gaccad877b20fca2d4a7eda5bebc1f5af1',1,'server.c']]],
  ['ssh_5fset_5fserver_5fcallbacks',['ssh_set_server_callbacks',['../group__libssh__callbacks.html#gaa321f33172cfa54eb50baaa963457a17',1,'ssh_set_server_callbacks(ssh_session session, ssh_server_callbacks cb):&#160;callbacks.c'],['../group__libssh__callbacks.html#gaa321f33172cfa54eb50baaa963457a17',1,'ssh_set_server_callbacks(ssh_session session, ssh_server_callbacks cb):&#160;callbacks.c']]],
  ['ssh_5fsilent_5fdisconnect',['ssh_silent_disconnect',['../group__libssh__session.html#gae1bd16255ba373325adf76307d0c8c42',1,'ssh_silent_disconnect(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gae1bd16255ba373325adf76307d0c8c42',1,'ssh_silent_disconnect(ssh_session session):&#160;session.c']]],
  ['ssh_5fstring_5fburn',['ssh_string_burn',['../group__libssh__string.html#gaca1c58e13e7bdb72ea8410592fa0cbf6',1,'string.c']]],
  ['ssh_5fstring_5fcopy',['ssh_string_copy',['../group__libssh__string.html#gac71b531c19ead0990fd23d0b28d92e02',1,'string.c']]],
  ['ssh_5fstring_5fdata',['ssh_string_data',['../group__libssh__string.html#gaf01673d22adbff92c88bcb6e30946ea6',1,'string.c']]],
  ['ssh_5fstring_5ffill',['ssh_string_fill',['../group__libssh__string.html#gad5626768334f4837c4a31e5b4a68d130',1,'string.c']]],
  ['ssh_5fstring_5ffree',['ssh_string_free',['../group__libssh__string.html#gacd9c4eb69f7ecfdcf709deb8dde6a5a8',1,'string.c']]],
  ['ssh_5fstring_5ffree_5fchar',['ssh_string_free_char',['../group__libssh__string.html#gafc10700722d6cafc468c2ee97585449a',1,'ssh_string_free_char(char *s):&#160;string.c'],['../group__libssh__string.html#gafc10700722d6cafc468c2ee97585449a',1,'ssh_string_free_char(char *s):&#160;string.c']]],
  ['ssh_5fstring_5ffrom_5fchar',['ssh_string_from_char',['../group__libssh__string.html#ga4154ea16ba2dc5bd5dcb2579686aaac2',1,'ssh_string_from_char(const char *what):&#160;string.c'],['../group__libssh__string.html#ga4154ea16ba2dc5bd5dcb2579686aaac2',1,'ssh_string_from_char(const char *what):&#160;string.c']]],
  ['ssh_5fstring_5fget_5fchar',['ssh_string_get_char',['../group__libssh__string.html#gaf867504fb528c32bf9e5e1459321cf59',1,'string.c']]],
  ['ssh_5fstring_5flen',['ssh_string_len',['../group__libssh__string.html#ga331553369afbfcb4f5300729ed65d0fe',1,'string.c']]],
  ['ssh_5fstring_5fnew',['ssh_string_new',['../group__libssh__string.html#gaedd3d6073cee901aaa288712896d0f28',1,'ssh_string_new(size_t size):&#160;string.c'],['../group__libssh__string.html#gaedd3d6073cee901aaa288712896d0f28',1,'ssh_string_new(size_t size):&#160;string.c']]],
  ['ssh_5fstring_5fto_5fchar',['ssh_string_to_char',['../group__libssh__string.html#ga65cbd5f2c5f02599c1c285efd1f06351',1,'string.c']]],
  ['ssh_5fthreads_5fset_5fcallbacks',['ssh_threads_set_callbacks',['../group__libssh__threads.html#gaf473af3fbae6f1bb0e249fd1d079ff68',1,'ssh_threads_set_callbacks(struct ssh_threads_callbacks_struct *cb):&#160;threads.c'],['../group__libssh__threads.html#gaf473af3fbae6f1bb0e249fd1d079ff68',1,'ssh_threads_set_callbacks(struct ssh_threads_callbacks_struct *cb):&#160;threads.c']]],
  ['ssh_5ftimeout_5fupdate',['ssh_timeout_update',['../group__libssh__misc.html#gad1c4b29e2421eb8f9ca111d98b0c2976',1,'ssh_timeout_update(struct ssh_timestamp *ts, int timeout):&#160;misc.c'],['../group__libssh__misc.html#gad1c4b29e2421eb8f9ca111d98b0c2976',1,'ssh_timeout_update(struct ssh_timestamp *ts, int timeout):&#160;misc.c']]],
  ['ssh_5fuserauth_5fagent',['ssh_userauth_agent',['../group__libssh__auth.html#ga7d84f3f89f65455b80b10e2643d80719',1,'ssh_userauth_agent(ssh_session session, const char *username):&#160;auth.c'],['../group__libssh__auth.html#ga7d84f3f89f65455b80b10e2643d80719',1,'ssh_userauth_agent(ssh_session session, const char *username):&#160;auth.c']]],
  ['ssh_5fuserauth_5fgssapi',['ssh_userauth_gssapi',['../group__libssh__auth.html#ga2758b0e86a848fe0d1d3d263d2a34d28',1,'ssh_userauth_gssapi(ssh_session session):&#160;auth.c'],['../group__libssh__auth.html#ga2758b0e86a848fe0d1d3d263d2a34d28',1,'ssh_userauth_gssapi(ssh_session session):&#160;auth.c']]],
  ['ssh_5fuserauth_5fkbdint',['ssh_userauth_kbdint',['../group__libssh__auth.html#ga6b3b1c2a045286d9476b0252791a07d2',1,'ssh_userauth_kbdint(ssh_session session, const char *user, const char *submethods):&#160;auth.c'],['../group__libssh__auth.html#ga6b3b1c2a045286d9476b0252791a07d2',1,'ssh_userauth_kbdint(ssh_session session, const char *user, const char *submethods):&#160;auth.c']]],
  ['ssh_5fuserauth_5fkbdint_5fgetinstruction',['ssh_userauth_kbdint_getinstruction',['../group__libssh__auth.html#gaa757fbdbd4f95261bbbbc12b1ec33078',1,'ssh_userauth_kbdint_getinstruction(ssh_session session):&#160;auth.c'],['../group__libssh__auth.html#gaa757fbdbd4f95261bbbbc12b1ec33078',1,'ssh_userauth_kbdint_getinstruction(ssh_session session):&#160;auth.c']]],
  ['ssh_5fuserauth_5fkbdint_5fgetname',['ssh_userauth_kbdint_getname',['../group__libssh__auth.html#gaf920b6f8ed1e3c53cc2a683230098657',1,'ssh_userauth_kbdint_getname(ssh_session session):&#160;auth.c'],['../group__libssh__auth.html#gaf920b6f8ed1e3c53cc2a683230098657',1,'ssh_userauth_kbdint_getname(ssh_session session):&#160;auth.c']]],
  ['ssh_5fuserauth_5fkbdint_5fgetnprompts',['ssh_userauth_kbdint_getnprompts',['../group__libssh__auth.html#gacb996ff4979670db009a71a90172ece9',1,'ssh_userauth_kbdint_getnprompts(ssh_session session):&#160;auth.c'],['../group__libssh__auth.html#gacb996ff4979670db009a71a90172ece9',1,'ssh_userauth_kbdint_getnprompts(ssh_session session):&#160;auth.c']]],
  ['ssh_5fuserauth_5fkbdint_5fgetprompt',['ssh_userauth_kbdint_getprompt',['../group__libssh__auth.html#ga4e7466c30852a3339003af7046fab396',1,'ssh_userauth_kbdint_getprompt(ssh_session session, unsigned int i, char *echo):&#160;auth.c'],['../group__libssh__auth.html#ga4e7466c30852a3339003af7046fab396',1,'ssh_userauth_kbdint_getprompt(ssh_session session, unsigned int i, char *echo):&#160;auth.c']]],
  ['ssh_5fuserauth_5fkbdint_5fsetanswer',['ssh_userauth_kbdint_setanswer',['../group__libssh__auth.html#ga75e44b1f27059a00080f80fac0107a20',1,'ssh_userauth_kbdint_setanswer(ssh_session session, unsigned int i, const char *answer):&#160;auth.c'],['../group__libssh__auth.html#ga75e44b1f27059a00080f80fac0107a20',1,'ssh_userauth_kbdint_setanswer(ssh_session session, unsigned int i, const char *answer):&#160;auth.c']]],
  ['ssh_5fuserauth_5flist',['ssh_userauth_list',['../group__libssh__auth.html#ga35d44897a44b4bb3b7c01108c1812a37',1,'ssh_userauth_list(ssh_session session, const char *username):&#160;auth.c'],['../group__libssh__auth.html#ga35d44897a44b4bb3b7c01108c1812a37',1,'ssh_userauth_list(ssh_session session, const char *username):&#160;auth.c']]],
  ['ssh_5fuserauth_5fnone',['ssh_userauth_none',['../group__libssh__auth.html#ga58e7c265236edbc97a2f117d3f23b4dd',1,'ssh_userauth_none(ssh_session session, const char *username):&#160;auth.c'],['../group__libssh__auth.html#ga58e7c265236edbc97a2f117d3f23b4dd',1,'ssh_userauth_none(ssh_session session, const char *username):&#160;auth.c']]],
  ['ssh_5fuserauth_5fpassword',['ssh_userauth_password',['../group__libssh__auth.html#ga50c0c150f8c4703e7ee49b3e3e3ca215',1,'ssh_userauth_password(ssh_session session, const char *username, const char *password):&#160;auth.c'],['../group__libssh__auth.html#ga50c0c150f8c4703e7ee49b3e3e3ca215',1,'ssh_userauth_password(ssh_session session, const char *username, const char *password):&#160;auth.c']]],
  ['ssh_5fuserauth_5fpublickey',['ssh_userauth_publickey',['../group__libssh__auth.html#gaa38c4f3194ef36720da7eddb0aa99e23',1,'ssh_userauth_publickey(ssh_session session, const char *username, const ssh_key privkey):&#160;auth.c'],['../group__libssh__auth.html#gaa38c4f3194ef36720da7eddb0aa99e23',1,'ssh_userauth_publickey(ssh_session session, const char *username, const ssh_key privkey):&#160;auth.c']]],
  ['ssh_5fuserauth_5fpublickey_5fauto',['ssh_userauth_publickey_auto',['../group__libssh__auth.html#ga53e6771b250c061463ed98b6e5b6e0af',1,'ssh_userauth_publickey_auto(ssh_session session, const char *username, const char *passphrase):&#160;auth.c'],['../group__libssh__auth.html#ga53e6771b250c061463ed98b6e5b6e0af',1,'ssh_userauth_publickey_auto(ssh_session session, const char *username, const char *passphrase):&#160;auth.c']]],
  ['ssh_5fuserauth_5ftry_5fpublickey',['ssh_userauth_try_publickey',['../group__libssh__auth.html#ga592f673c4d417a6a46cd4876ac8287aa',1,'ssh_userauth_try_publickey(ssh_session session, const char *username, const ssh_key pubkey):&#160;auth.c'],['../group__libssh__auth.html#ga592f673c4d417a6a46cd4876ac8287aa',1,'ssh_userauth_try_publickey(ssh_session session, const char *username, const ssh_key pubkey):&#160;auth.c']]],
  ['ssh_5fversion',['ssh_version',['../group__libssh__misc.html#gaeda71ed34a62fa332762f25b14dac6eb',1,'ssh_version(int req_version):&#160;misc.c'],['../group__libssh__misc.html#gaeda71ed34a62fa332762f25b14dac6eb',1,'ssh_version(int req_version):&#160;misc.c']]],
  ['ssh_5fwrite_5fknownhost',['ssh_write_knownhost',['../group__libssh__session.html#gaf61a9cfdc40c76ffce9f9a8543755d36',1,'ssh_write_knownhost(ssh_session session):&#160;known_hosts.c'],['../group__libssh__session.html#gaf61a9cfdc40c76ffce9f9a8543755d36',1,'ssh_write_knownhost(ssh_session session):&#160;known_hosts.c']]]
];
